/***************************************************************************
 *   Copyright (C) 2007 by Gabriel Menezes Nunes   *
 *   gabriel@msnshadow   *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/


#include "configdlg.h"

#include <qvariant.h>
#include <qpushbutton.h>
#include <qlabel.h>
#include <qlineedit.h>
#include <qcheckbox.h>
#include <qlayout.h>
#include <qtooltip.h>
#include <qwhatsthis.h>

#include <sys/ioctl.h>
#include <net/if.h>
#include <unistd.h>
#include <arpa/inet.h>
#include <stdio.h>

/*
 *  Constructs a configDlg as a child of 'parent', with the
 *  name 'name' and widget flags set to 'f'.
 *
 *  The dialog will by default be modeless, unless you set 'modal' to
 *  TRUE to construct a modal dialog.
 */
configDlg::configDlg( QWidget* parent, const char* name, bool modal, WFlags fl )
    : QDialog( parent, name, modal, fl )
{
    if ( !name )
	setName( "configDlg" );

    defaultButton = new QPushButton( this, "defaultButton" );
    defaultButton->setGeometry( QRect( 390, 420, 110, 24 ) );

    okButton = new QPushButton( this, "okButton" );
    okButton->setGeometry( QRect( 50, 420, 110, 24 ) );

    cancelButton = new QPushButton( this, "cancelButton" );
    cancelButton->setGeometry( QRect( 220, 420, 110, 24 ) );

    

    textLabel1_4_2 = new QLabel( this, "textLabel1_4_2" );
    textLabel1_4_2->setGeometry( QRect( 250, 0, 62, 37 ) );

    textLabel3 = new QLabel( this, "textLabel3" );
    textLabel3->setGeometry( QRect( 130, 40, 102, 20 ) );

   

	videoBox = new QComboBox( FALSE, this, "videoBox" );
    videoBox->setGeometry( QRect( 190, 360, 230, 22 ) );

textBox = new QComboBox( FALSE, this, "textBox" );
    textBox->setGeometry( QRect( 200, 130, 230, 22 ) );

interLabel1 = new QLabel( this, "interLabel1" );
    interLabel1->setGeometry( QRect( 130, 130, 60, 20 ) );

    interLabel2 = new QLabel( this, "interLabel2" );
    interLabel2->setGeometry( QRect( 120, 360, 60, 20 ) );
interLabel1->setText( tr( "Interface:" ) );
    interLabel2->setText( tr( "Interface:" ) );


    textEdit = new QLineEdit( this, "textEdit" );
    textEdit->setGeometry( QRect( 240, 40, 240, 22 ) );

    textLabel1_4 = new QLabel( this, "textLabel1_4" );
    textLabel1_4->setGeometry( QRect( 250, 170, 77, 37 ) );

    

    textLabel4 = new QLabel( this, "textLabel4" );
    textLabel4->setGeometry( QRect( 120, 220, 102, 20 ) );

    videoEdit = new QLineEdit( this, "videoEdit" );
    videoEdit->setGeometry( QRect( 230, 220, 240, 22 ) );

    checkVideo = new QCheckBox( this, "checkVideo" );
    checkVideo->setGeometry( QRect( 140, 250, 320, 20 ) );

    checkAuto = new QCheckBox( this, "checkAuto" );
    checkAuto->setGeometry( QRect( 140, 280, 320, 20 ) );

    checkText = new QCheckBox( this, "checkText" );
    checkText->setGeometry( QRect( 130, 90, 320, 20 ) );

    textLabel2_3 = new QLabel( this, "textLabel2_3" );
    textLabel2_3->setGeometry( QRect( 110, 310, 100, 20 ) );

    mencoderEdit = new QLineEdit( this, "mencoderEdit" );
    mencoderEdit->setGeometry( QRect( 220, 310, 190, 22 ) );

    findButton = new QPushButton( this, "findButton" );
    findButton->setGeometry( QRect( 420, 310, 50, 24 ) );
    languageChange();
    resize( QSize(600, 470).expandedTo(minimumSizeHint()) );
    clearWState( WState_Polished );
	connect(cancelButton, SIGNAL(clicked()), this, SLOT(close()));
	connect(findButton, SIGNAL(clicked()), this, SLOT(findMencoder()));
	connect(defaultButton, SIGNAL(clicked()), this, SLOT(setDefault()));
	connect(okButton, SIGNAL(clicked()), this, SLOT(okClicked()));
	connect(checkAuto, SIGNAL(clicked()), this, SLOT(checkAutoClicked()));
	videoString = QString("port 80");
	videoEdit->setText(videoString);
	
	textString = QString("port 1863");
	textEdit->setText(textString);
	ignoreVideo = ignoreText = false;
	proc  = new QProcess(this);
	mencoderString = QString("");
	proc->addArgument("which");
	proc->addArgument("mencoder");
	connect(proc, SIGNAL(processExited()), this, SLOT(processOut()));
	connect(proc, SIGNAL(readyReadStdout()), this, SLOT(readProc()));
	getInterfaces();
	videoBox->setCurrentItem(0);
	textBox->setCurrentItem(0);
	currentVideo = currentText = (*listInterface.begin());
	
	videoBoxIndex = textBoxIndex = 0;
	if( !(proc->start()))
		return;
	
}

void configDlg::processOut() {
	;
}

void configDlg::checkAutoClicked() {

 if(checkAuto->isChecked())
	videoEdit->setEnabled(false);
 else
	videoEdit->setEnabled(true);

}

void configDlg::findMencoder() {
	QString findS = QFileDialog::getOpenFileName(QDir::home().path(), "Binaries (*)", this, 0, "Choose mencoder binary");
	mencoderEdit->setText(findS);
}

void configDlg::readProc() {
	mencoderString = QString(proc->readStdout());
	mencoderString = mencoderString.mid(0, mencoderString.length() - 1);
	mencoderEdit->setText(mencoderString);
}

void configDlg::getInterfaces() {

	int i;
      int s = socket (AF_INET, SOCK_DGRAM, 0);

      for (i=1;;i++)
{
          struct ifreq ifr;
          struct sockaddr_in *sin = (struct sockaddr_in *) &ifr.ifr_addr;
          

          ifr.ifr_ifindex = i;
          if (ioctl (s, SIOCGIFNAME, &ifr) < 0)
            break;
	interClass *inter = new interClass(QString(ifr.ifr_name));

          /* now ifr.ifr_name is set */
          if (ioctl (s, SIOCGIFADDR, &ifr) >= 0){
			inter->ip = QString(inet_ntoa(sin->sin_addr));
}
      
		
         

         
	char merda[100];
	memset(merda, 0x00, 100);
          if(ioctl(s, SIOCGIFHWADDR, &ifr) >=  0){

              sprintf(merda, "%2.2x:%2.2x:%2.2x:%2.2x:%2.2x:%2.2x",ifr.ifr_hwaddr.sa_data[0], ifr.ifr_hwaddr.sa_data[1],ifr.ifr_hwaddr.sa_data[2],ifr.ifr_hwaddr.sa_data[3],ifr.ifr_hwaddr.sa_data[4],ifr.ifr_hwaddr.sa_data[5]);
		inter->mac = cutF(merda);
		inter->mac = inter->mac.upper();
		
          }
		
		listInterface.push_back(inter);
		videoBox->insertItem(QString(ifr.ifr_name));
		textBox->insertItem(QString(ifr.ifr_name));
		
}

}

QString configDlg::cutF(const char* cut) {
	QString str(cut);
	QString laia;
	int index, index2;
	index = index2 = 0;
	for(int i = 0; i < 5;i++) {
	index2 = str.find(':',index2+1);
	laia.append(str.mid(index2-2, 2));
	laia.append(':');
	
}
	laia.append(str.mid(str.length() - 2, 2));
	laia.replace("00", "0");
	laia.replace(":0", ":");
	return laia;
	
}

/*
 *  Destroys the object and frees any allocated resources
 */
configDlg::~configDlg()
{
    // no need to delete child widgets, Qt does it all for us
}

/*
 *  Sets the strings of the subwidgets using the current
 *  language.
 */
void configDlg::languageChange()
{
    setCaption( tr( "Configuration" ) );
    defaultButton->setText( tr( "Set Default" ) );
    okButton->setText( tr( "Ok" ) );
    cancelButton->setText( tr( "Cancel" ) );
    
    textLabel1_4_2->setText( tr( "<font size=\"+3\">Text</font>" ) );
    textLabel3->setText( tr( "Rule for Sniffing:" ) );
    
    textLabel1_4->setText( tr( "<font size=\"+3\">Video</font>" ) );
   
    textLabel4->setText( tr( "Rule for Sniffing:" ) );
    checkVideo->setText( tr( "Ignore packets with source MAC of the interface" ) );
    checkText->setText( tr( "Ignore packets with source MAC of the interface" ) );
    checkAuto->setText( tr( "Video Auto Detection"));
    textLabel2_3->setText( tr( "mencoder path:" ) );
    findButton->setText( tr( "Find" ) );
}

void configDlg::okClicked() {
videoString = videoEdit->text();

textString = textEdit->text();
ignoreVideo = checkVideo->isChecked();
ignoreText = checkText->isChecked();
videoBoxIndex = videoBox->currentItem();
textBoxIndex = textBox->currentItem();
mencoderString = mencoderEdit->text();
mencoderString.replace(' ', "");
std::list<interClass*>::iterator it = listInterface.begin();
while(it != listInterface.end()) {
	if( (*it)->name == textBox->text(textBoxIndex) ){
		currentText = (*it);
}
	if( (*it)->name == videoBox->text(videoBoxIndex) ){
		currentVideo = (*it);
}
it++;
}
close();

}

void configDlg::closeEvent(QCloseEvent *e) {
videoEdit->setText(videoString);

textEdit->setText(textString);

checkVideo->setChecked(ignoreVideo);
checkText->setChecked(ignoreText);
videoBox->setCurrentItem(videoBoxIndex);
textBox->setCurrentItem(textBoxIndex);
mencoderEdit->setText(mencoderString);
e->accept();


}

void configDlg::setDefault() {

textEdit->setText("port 1863");
videoEdit->setText("port 80");

checkVideo->setChecked(false);
checkText->setChecked(false);

}

