/***************************************************************************
 *   Copyright (C) 2007 by Gabriel Menezes Nunes   *
 *   gabriel@msnshadow   *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#include "msnshadowitemmsg.h"
#include <qpainter.h>
#include <qpixmap.h>
#include <qfont.h>
#include <qimage.h>


static const unsigned char image1_data[] = { 
    0x89, 0x50, 0x4e, 0x47, 0x0d, 0x0a, 0x1a, 0x0a, 0x00, 0x00, 0x00, 0x0d,
    0x49, 0x48, 0x44, 0x52, 0x00, 0x00, 0x00, 0x40, 0x00, 0x00, 0x00, 0x40,
    0x08, 0x06, 0x00, 0x00, 0x00, 0xaa, 0x69, 0x71, 0xde, 0x00, 0x00, 0x19,
    0x49, 0x49, 0x44, 0x41, 0x54, 0x78, 0x9c, 0xed, 0x9b, 0x69, 0x8c, 0x5e,
    0xd7, 0x79, 0xdf, 0x7f, 0x67, 0xb9, 0xdb, 0xbb, 0xcc, 0x3e, 0x1c, 0x72,
    0x46, 0x5c, 0x44, 0x8a, 0xa6, 0x44, 0x49, 0x94, 0x15, 0x39, 0xb1, 0xbc,
    0x45, 0x32, 0x02, 0xb9, 0x32, 0x62, 0x23, 0x6e, 0xe1, 0x02, 0x6d, 0x83,
    0x04, 0x75, 0xed, 0xda, 0x4d, 0x5b, 0xb7, 0x1f, 0x92, 0x0f, 0x6d, 0x13,
    0x34, 0x75, 0x81, 0xc6, 0x69, 0x0b, 0x34, 0x6e, 0x1b, 0x27, 0xb0, 0x9b,
    0xc6, 0xb1, 0x8b, 0x24, 0x46, 0xdc, 0x38, 0x29, 0xd2, 0x26, 0x5e, 0x62,
    0xa9, 0xb2, 0x15, 0xd1, 0x96, 0x64, 0x5b, 0xa2, 0x24, 0x52, 0x94, 0xc4,
    0x55, 0xdc, 0x67, 0x38, 0xf3, 0xce, 0xbb, 0xde, 0xe5, 0x2c, 0xfd, 0x70,
    0xee, 0x3b, 0x1c, 0xd9, 0xb4, 0x2c, 0xd1, 0x62, 0x5c, 0x20, 0x39, 0xc0,
    0xc5, 0x9d, 0x77, 0x30, 0xef, 0xb9, 0xf7, 0xfc, 0xcf, 0x73, 0xfe, 0xcf,
    0xff, 0x59, 0x06, 0xfe, 0x7a, 0xfc, 0xf5, 0xf8, 0x2b, 0x3d, 0xc4, 0x0f,
    0xfb, 0x05, 0xc6, 0x23, 0x3b, 0x70, 0xff, 0xd2, 0xcc, 0x7d, 0x1f, 0x78,
    0x6f, 0xda, 0x6c, 0xbd, 0x3d, 0x6a, 0xb4, 0xf6, 0xeb, 0xc6, 0xe4, 0x56,
    0xef, 0xbd, 0x28, 0xbb, 0xab, 0x17, 0x47, 0xeb, 0x9d, 0x67, 0x06, 0xeb,
    0xfd, 0xaf, 0xf5, 0x1e, 0xfe, 0xcc, 0xff, 0x34, 0x47, 0xbe, 0x74, 0xf2,
    0xb5, 0x7c, 0xee, 0x0f, 0x1d, 0x80, 0xec, 0xf6, 0xfb, 0xb6, 0x2c, 0xbc,
    0xeb, 0xc3, 0xbf, 0x32, 0x77, 0xe3, 0xbe, 0xbf, 0xb7, 0x30, 0x3f, 0x99,
    0x4d, 0xb7, 0x22, 0x9a, 0xb1, 0x44, 0x4b, 0x81, 0xf3, 0x8e, 0xa2, 0xb2,
    0x74, 0x06, 0x25, 0xcb, 0xab, 0x23, 0xce, 0x9c, 0x59, 0x29, 0x2e, 0x1d,
    0x79, 0xea, 0x73, 0xc3, 0x83, 0xbf, 0xff, 0x2f, 0xfd, 0xf1, 0x07, 0xce,
    0xbc, 0x16, 0xcf, 0xff, 0xa1, 0x02, 0x30, 0xf7, 0xd3, 0xff, 0xe1, 0x3d,
    0x8b, 0x6f, 0x7c, 0xc7, 0x7f, 0xdf, 0xb3, 0x6b, 0xdb, 0xcc, 0x0d, 0xb3,
    0x09, 0x53, 0x99, 0x26, 0x89, 0xc2, 0xe2, 0xf1, 0xe0, 0xbc, 0xc7, 0x58,
    0x47, 0x5e, 0x5a, 0x7a, 0xa3, 0x82, 0x0b, 0xab, 0x7d, 0x5e, 0x38, 0xb5,
    0xc2, 0x89, 0xa7, 0x4f, 0x74, 0x7a, 0x4f, 0x7e, 0xf5, 0x43, 0xf6, 0xb1,
    0x8f, 0xff, 0xc1, 0x0f, 0xfa, 0x0e, 0xea, 0xb5, 0x58, 0xc8, 0xb5, 0x8c,
    0xf9, 0x9f, 0xfd, 0xcf, 0x1f, 0xdc, 0x7d, 0xcf, 0x4f, 0x7e, 0xfa, 0xc0,
    0xde, 0x85, 0xe6, 0x9e, 0x85, 0x8c, 0xd9, 0x66, 0x4c, 0x23, 0xd1, 0xc4,
    0x5a, 0xa1, 0x95, 0x42, 0x49, 0x90, 0x52, 0x20, 0x25, 0x28, 0x21, 0x90,
    0x42, 0xa0, 0xa5, 0x27, 0xd2, 0x16, 0x11, 0xf9, 0x74, 0xe8, 0x27, 0xdf,
    0x5b, 0xaa, 0x6d, 0xab, 0xfe, 0xfc, 0x63, 0x8f, 0xfe, 0x20, 0xef, 0xf1,
    0x43, 0x01, 0xa0, 0xfd, 0xee, 0x5f, 0x7a, 0xd7, 0x8e, 0xb7, 0xdd, 0xff,
    0xe9, 0x03, 0x37, 0xcd, 0xeb, 0x1b, 0x66, 0x33, 0x26, 0xd2, 0x98, 0x38,
    0x52, 0x28, 0x29, 0x11, 0x4a, 0x22, 0xbc, 0xc7, 0x21, 0xf0, 0xde, 0xe3,
    0x5c, 0xb8, 0x8c, 0x73, 0x18, 0x6b, 0x31, 0xa6, 0xc2, 0xd9, 0x02, 0x4f,
    0x29, 0x46, 0x26, 0x7b, 0x47, 0x25, 0x66, 0x9e, 0x61, 0xf9, 0xd0, 0x91,
    0x6b, 0x7d, 0x17, 0x7d, 0x2d, 0x5f, 0x6a, 0xcd, 0xe9, 0xec, 0x8e, 0xfb,
    0x66, 0xee, 0xd9, 0x7d, 0x60, 0xe6, 0x0d, 0x3a, 0xd2, 0x37, 0x08, 0xc1,
    0xda, 0xa5, 0x53, 0xfd, 0x43, 0x4f, 0x7e, 0x65, 0xf9, 0xc1, 0x17, 0x9f,
    0x19, 0x5c, 0x78, 0xb9, 0xef, 0xca, 0x9d, 0x77, 0x6f, 0x99, 0xda, 0x77,
    0xd7, 0x6f, 0xed, 0xda, 0xda, 0x8a, 0xe6, 0x5a, 0x11, 0x69, 0xa4, 0x51,
    0xf5, 0x36, 0x78, 0xef, 0x71, 0xc6, 0xd5, 0x0b, 0x77, 0x18, 0xe7, 0x71,
    0xd6, 0x53, 0x39, 0x87, 0xb1, 0x0e, 0x67, 0x1d, 0x08, 0x41, 0x14, 0x69,
    0x5a, 0x13, 0x31, 0x33, 0x0b, 0xa9, 0x32, 0xdd, 0xd7, 0x7d, 0xa2, 0xb8,
    0x7c, 0xe7, 0x41, 0x7f, 0xf1, 0xdb, 0xe7, 0xae, 0x65, 0x2d, 0xaf, 0x1a,
    0x80, 0x7b, 0xff, 0xe1, 0xec, 0xfb, 0x6e, 0xba, 0x7d, 0xeb, 0x47, 0x76,
    0xdc, 0xb8, 0x6d, 0xfb, 0xe4, 0xd4, 0x24, 0x71, 0x1c, 0xe3, 0x9c, 0x63,
    0xf8, 0xfa, 0x21, 0xb7, 0xdc, 0xbd, 0x32, 0x3a, 0x79, 0xe4, 0xd2, 0x6f,
    0x7c, 0xe5, 0xb7, 0x4f, 0x7f, 0x64, 0xf5, 0x6c, 0xd5, 0xbb, 0xda, 0xf7,
    0xb3, 0x5b, 0xdf, 0xf1, 0xaf, 0xa6, 0xe7, 0xda, 0x0b, 0xed, 0x54, 0xa0,
    0xa4, 0x00, 0xef, 0x30, 0x06, 0xa4, 0xf0, 0xf8, 0x31, 0x08, 0xce, 0x63,
    0x9d, 0xaf, 0x39, 0xc0, 0x53, 0x59, 0x43, 0x59, 0x1a, 0x2a, 0x63, 0xb0,
    0xd6, 0x22, 0x04, 0x68, 0xad, 0xc8, 0x5a, 0x31, 0xcd, 0xd9, 0xd6, 0xac,
    0xdb, 0x75, 0xf7, 0x2f, 0x97, 0x17, 0xbf, 0xfd, 0xa1, 0xeb, 0x0a, 0x80,
    0xd4, 0xa8, 0xb7, 0xbc, 0xaf, 0xf5, 0x89, 0xdb, 0xde, 0xbc, 0xf4, 0xfe,
    0x9b, 0x76, 0xdf, 0xc4, 0x96, 0x85, 0x2d, 0x34, 0x9b, 0x4d, 0x54, 0xbd,
    0x7d, 0xc6, 0x18, 0x16, 0x16, 0x16, 0xb2, 0xa9, 0x99, 0x89, 0x9f, 0x4f,
    0xda, 0xdc, 0xf7, 0xf0, 0x1f, 0x9c, 0x79, 0xe7, 0xc9, 0xc7, 0x8b, 0x97,
    0xec, 0x8a, 0x98, 0xdc, 0x31, 0x13, 0xb7, 0x67, 0xde, 0x9f, 0x6a, 0x83,
    0x73, 0x96, 0xaa, 0x32, 0xe4, 0x4a, 0xa1, 0x95, 0x0f, 0x74, 0xec, 0xc1,
    0x31, 0x06, 0xc0, 0x61, 0xad, 0xc7, 0x5a, 0x87, 0xb1, 0x86, 0xa2, 0xaa,
    0xc8, 0xcb, 0x82, 0xb2, 0x2c, 0xb1, 0xc6, 0x22, 0x00, 0x1d, 0x07, 0x10,
    0x8a, 0xd9, 0x85, 0x9f, 0x31, 0x53, 0xbb, 0x7e, 0xd9, 0x75, 0x4e, 0xbe,
    0xac, 0xf5, 0xfd, 0x40, 0x00, 0xdc, 0xf1, 0xb7, 0xd4, 0xbf, 0xdb, 0xb5,
    0x7f, 0xf6, 0xfd, 0x0b, 0x5b, 0x16, 0x98, 0x98, 0x9c, 0xa0, 0xd1, 0x68,
    0x90, 0x24, 0x09, 0x4a, 0x2a, 0x84, 0x14, 0x38, 0xe7, 0x90, 0x52, 0xe2,
    0x9c, 0xa3, 0xc8, 0x8b, 0x03, 0xbd, 0xfb, 0xfb, 0x7f, 0x72, 0xf1, 0x85,
    0x4b, 0x6f, 0x1d, 0x75, 0xfc, 0x68, 0x3c, 0x47, 0xb4, 0xeb, 0xad, 0xef,
    0x8e, 0x62, 0xd9, 0x72, 0xa6, 0x60, 0x34, 0x1a, 0xd2, 0x1b, 0xa4, 0x18,
    0x6b, 0xd1, 0x5a, 0x21, 0x85, 0xc4, 0x7b, 0xf0, 0xde, 0xe1, 0xbc, 0xc7,
    0x3a, 0x8b, 0xb3, 0x63, 0x20, 0x2c, 0x45, 0x55, 0x32, 0x2a, 0x8a, 0x00,
    0x82, 0xa9, 0x70, 0xde, 0x23, 0x95, 0x22, 0x4a, 0x23, 0x92, 0x56, 0x23,
    0xab, 0x6e, 0xfa, 0xf1, 0x9f, 0x2a, 0x1e, 0x3f, 0xf9, 0x89, 0xeb, 0x02,
    0xc0, 0xe2, 0x1d, 0xbc, 0x7e, 0x66, 0xbb, 0xfe, 0xf9, 0x2c, 0xcb, 0x00,
    0xb0, 0xd6, 0x62, 0x8c, 0xc1, 0x18, 0x83, 0x57, 0x20, 0x7d, 0xf0, 0xa6,
    0x42, 0x4a, 0xb4, 0xd6, 0xb4, 0x5a, 0x2d, 0xe6, 0x17, 0x27, 0x7f, 0xe4,
    0x8e, 0x9f, 0x5a, 0xff, 0xe7, 0x5f, 0xff, 0x74, 0xfe, 0xab, 0xe3, 0x79,
    0x64, 0xa3, 0xfd, 0x0e, 0x49, 0x45, 0x39, 0x1c, 0xd2, 0xeb, 0x75, 0x51,
    0x4a, 0x91, 0x97, 0x09, 0x91, 0x8e, 0x90, 0x32, 0xcc, 0xe1, 0x3d, 0x38,
    0xe7, 0x70, 0xde, 0x05, 0x02, 0xf4, 0x1e, 0x63, 0x2d, 0x95, 0xa9, 0x28,
    0xcb, 0x8a, 0x22, 0x2f, 0x30, 0xc6, 0x40, 0x0d, 0x80, 0x8a, 0x23, 0xa2,
    0x34, 0x42, 0x37, 0x27, 0xee, 0x2b, 0xe0, 0xfa, 0x00, 0x30, 0xb7, 0x47,
    0x7c, 0x58, 0xc7, 0x4a, 0x57, 0x65, 0xc9, 0x60, 0x30, 0xa0, 0xd7, 0xeb,
    0xa1, 0x94, 0xa2, 0x2c, 0x4b, 0x74, 0xa4, 0xd1, 0x4a, 0x23, 0x85, 0xa4,
    0xac, 0x4a, 0xf2, 0x3c, 0xa7, 0xaa, 0x0c, 0x51, 0x14, 0xd1, 0x9c, 0x91,
    0xff, 0x38, 0x6e, 0xf2, 0x6b, 0xe5, 0x80, 0x02, 0x40, 0x08, 0x77, 0xa3,
    0x33, 0x15, 0xc5, 0x70, 0x44, 0x7f, 0xbd, 0x0b, 0xc0, 0x28, 0x4d, 0xd1,
    0x91, 0x46, 0x09, 0xb5, 0xa1, 0x4a, 0xbc, 0xf7, 0x78, 0x0f, 0xd4, 0xd6,
    0xe0, 0x9c, 0xdf, 0xf0, 0x00, 0xa6, 0x34, 0x38, 0x13, 0xc8, 0x50, 0x45,
    0x1a, 0x1d, 0xc7, 0xe8, 0x38, 0x42, 0x46, 0xf1, 0xee, 0x57, 0xbb, 0xf8,
    0x57, 0x04, 0x80, 0x54, 0x48, 0x9d, 0x88, 0xfb, 0x9c, 0x73, 0x0c, 0x86,
    0x43, 0x3a, 0xeb, 0xeb, 0x48, 0xa5, 0x30, 0x95, 0x21, 0xcd, 0x52, 0x22,
    0xad, 0x51, 0x5a, 0x23, 0xa5, 0xa4, 0x2c, 0x4b, 0x7a, 0xfd, 0x3e, 0xdd,
    0xee, 0x3a, 0x79, 0x5e, 0x10, 0x65, 0x62, 0xfb, 0xec, 0x1e, 0x6e, 0x3f,
    0x7f, 0x88, 0xc7, 0xc3, 0x6c, 0x62, 0xca, 0x55, 0x15, 0xc5, 0x60, 0x48,
    0x7f, 0xbd, 0x8b, 0xb5, 0x96, 0x38, 0x4b, 0xd0, 0x51, 0xb4, 0x71, 0x94,
    0xc4, 0x18, 0x05, 0x11, 0xc4, 0x90, 0xc7, 0x07, 0x62, 0xac, 0x3d, 0x83,
    0xb3, 0x0e, 0x0f, 0x48, 0xa9, 0xd0, 0x51, 0x14, 0x16, 0x1f, 0x6b, 0x54,
    0x1c, 0x4f, 0x5e, 0x17, 0x00, 0x74, 0xca, 0x84, 0x4e, 0xfc, 0x56, 0x6b,
    0x0d, 0x45, 0x51, 0xd0, 0xef, 0xf5, 0x00, 0x4f, 0x59, 0x14, 0x64, 0x59,
    0x46, 0x14, 0x45, 0x81, 0x08, 0xbd, 0xa7, 0x28, 0x4b, 0xfa, 0xfd, 0x3e,
    0xdd, 0x6e, 0x97, 0x5e, 0xaf, 0x8b, 0x31, 0x86, 0xd6, 0x1c, 0xdb, 0xa1,
    0x06, 0xc0, 0x5b, 0xe7, 0x4c, 0x45, 0x35, 0xcc, 0xc9, 0xe3, 0x01, 0xce,
    0x39, 0xaa, 0xa2, 0x44, 0x45, 0x1a, 0xa9, 0x14, 0x42, 0x49, 0xa4, 0x10,
    0x80, 0xd8, 0xf4, 0x73, 0x0d, 0x06, 0xe3, 0x0b, 0x84, 0x10, 0x08, 0xad,
    0xd1, 0x42, 0xa0, 0xe3, 0x08, 0xa5, 0x35, 0x42, 0x0a, 0x77, 0x5d, 0x00,
    0x10, 0x02, 0x09, 0x22, 0x3c, 0x54, 0x04, 0xb2, 0x2b, 0x8b, 0x92, 0x01,
    0x03, 0xca, 0xb2, 0x24, 0xd2, 0x11, 0x00, 0xc6, 0x54, 0xe4, 0x45, 0xc1,
    0x60, 0x30, 0x64, 0x38, 0x1c, 0x30, 0x1c, 0x0e, 0xa9, 0x0a, 0x03, 0x9b,
    0xc4, 0x96, 0xb7, 0xd5, 0x8a, 0xab, 0x0c, 0xa6, 0x2c, 0x29, 0x47, 0x05,
    0x00, 0xae, 0xb2, 0xc8, 0x48, 0x21, 0x6b, 0x2b, 0x92, 0x4a, 0x21, 0xa5,
    0x40, 0x48, 0x89, 0xac, 0x85, 0x91, 0x94, 0x12, 0x21, 0x75, 0x50, 0x86,
    0x4a, 0xa1, 0xa4, 0x02, 0x29, 0xb0, 0x52, 0x22, 0xb5, 0x46, 0x48, 0x09,
    0xde, 0x5c, 0xbe, 0x2e, 0x00, 0x54, 0x39, 0x5d, 0x93, 0xfb, 0x0e, 0x5e,
    0xcc, 0x6b, 0xad, 0x49, 0x93, 0x24, 0xb0, 0xbf, 0x52, 0x21, 0x58, 0x29,
    0x8b, 0xb0, 0x93, 0x55, 0xc5, 0x68, 0x34, 0x62, 0x38, 0x1c, 0x32, 0x1c,
    0x0e, 0x19, 0x0d, 0x73, 0xca, 0x21, 0xf4, 0x57, 0xc4, 0x05, 0xf0, 0x61,
    0x32, 0xe7, 0x8f, 0x3a, 0x63, 0xef, 0xb1, 0x55, 0x85, 0x2d, 0x4b, 0x8c,
    0x94, 0x78, 0x2f, 0xd0, 0x3e, 0x08, 0x1e, 0xa5, 0x14, 0x4e, 0x7b, 0xa4,
    0x92, 0x48, 0xe9, 0x03, 0xc1, 0x0a, 0x81, 0x50, 0xa2, 0x5e, 0xbc, 0x0e,
    0x7c, 0xa1, 0x34, 0x42, 0x08, 0xf0, 0x65, 0x98, 0xd6, 0x3a, 0xf0, 0xee,
    0xd9, 0x6b, 0x01, 0x40, 0x7e, 0xbf, 0x3f, 0x70, 0x06, 0x93, 0x77, 0xf9,
    0x0b, 0x6b, 0x82, 0x9b, 0x8b, 0xe2, 0x98, 0x46, 0xd6, 0xa0, 0xd9, 0x6c,
    0xd2, 0xc8, 0x1a, 0xa4, 0x69, 0x4a, 0x1c, 0xc7, 0x44, 0x51, 0x84, 0x94,
    0x12, 0x7c, 0xd0, 0x04, 0x55, 0x0e, 0x79, 0x97, 0xb5, 0xce, 0x29, 0xff,
    0xc4, 0x78, 0x2e, 0xd3, 0x3d, 0xf7, 0xbf, 0x9c, 0xb5, 0x38, 0x63, 0xb1,
    0xc6, 0xe2, 0x9c, 0xc3, 0x7b, 0x87, 0x77, 0x3e, 0x9c, 0x77, 0x0f, 0xb8,
    0x70, 0xe6, 0xa9, 0x2d, 0x4e, 0x4a, 0x89, 0x92, 0x0a, 0xad, 0x23, 0xa2,
    0x38, 0x26, 0xae, 0x2f, 0xad, 0x23, 0x90, 0x02, 0x67, 0x1d, 0xce, 0x18,
    0xaa, 0xd5, 0x73, 0xff, 0xfb, 0xba, 0x00, 0x00, 0xd0, 0x79, 0x91, 0x8f,
    0x0f, 0x3b, 0x57, 0x76, 0x5b, 0x48, 0x41, 0x14, 0x45, 0xa4, 0x69, 0x1a,
    0xae, 0x24, 0x0d, 0x00, 0x28, 0x89, 0xf3, 0x0e, 0x53, 0x39, 0xcc, 0x10,
    0x86, 0xab, 0xfe, 0xd3, 0xa3, 0x75, 0xfa, 0x1b, 0x00, 0x9c, 0x7e, 0xfc,
    0x41, 0x3b, 0xea, 0x9f, 0x77, 0x95, 0xc1, 0x19, 0x0b, 0x1e, 0x84, 0x90,
    0x81, 0x69, 0x95, 0x0a, 0x47, 0x21, 0xd6, 0x28, 0x1d, 0xce, 0xb5, 0x8a,
    0x23, 0x74, 0x9c, 0x10, 0x25, 0x29, 0x71, 0x92, 0x92, 0x24, 0x09, 0x71,
    0x1c, 0x9e, 0x25, 0x24, 0x58, 0x63, 0xa9, 0x8a, 0x92, 0xa2, 0xdb, 0x59,
    0x1e, 0x1e, 0x7e, 0xe0, 0x0b, 0xd7, 0x02, 0xc0, 0x2b, 0x0a, 0x86, 0x7a,
    0x97, 0x38, 0x9e, 0xb4, 0xb8, 0x25, 0x6e, 0x9a, 0xdb, 0xe2, 0x4c, 0xa2,
    0xc7, 0x26, 0x48, 0xf0, 0xd9, 0x65, 0x55, 0x52, 0x14, 0x39, 0xc3, 0xfe,
    0x90, 0x5e, 0xbf, 0x47, 0x7f, 0xb5, 0xa2, 0xbf, 0xe2, 0xcf, 0x9c, 0x79,
    0xc2, 0xff, 0x74, 0xd9, 0x67, 0xb8, 0x31, 0x91, 0x29, 0x8c, 0x9c, 0xde,
    0xe1, 0x45, 0x3a, 0xf1, 0x37, 0x54, 0x14, 0xa1, 0x92, 0x84, 0x28, 0x4b,
    0x88, 0xd2, 0x18, 0x9d, 0xc6, 0xe8, 0x24, 0x26, 0x8a, 0xea, 0x7b, 0x1c,
    0xae, 0x38, 0x49, 0x88, 0x93, 0x84, 0x24, 0x4e, 0x6a, 0x4b, 0x53, 0x78,
    0x2f, 0x28, 0xab, 0x8a, 0x7e, 0xaf, 0x4f, 0x6f, 0xa5, 0x43, 0xef, 0xe4,
    0xd1, 0x8f, 0x8e, 0x0e, 0x3f, 0xf0, 0x95, 0xeb, 0x06, 0x00, 0xc0, 0xa8,
    0xc3, 0x9f, 0x0b, 0xe5, 0xef, 0x71, 0x32, 0xdf, 0x6e, 0x45, 0x49, 0x55,
    0x55, 0xe4, 0x79, 0xc1, 0x70, 0x30, 0xac, 0x99, 0x7f, 0x9d, 0xce, 0xda,
    0x3a, 0xeb, 0x97, 0x72, 0xba, 0xe7, 0xfd, 0xc5, 0xb5, 0x17, 0x79, 0xf7,
    0xe5, 0x63, 0x1c, 0xfb, 0xce, 0x79, 0xec, 0xfa, 0xb9, 0x27, 0xc5, 0xf4,
    0xee, 0x77, 0x89, 0x28, 0xdb, 0xaa, 0xd3, 0x84, 0x28, 0x4b, 0x89, 0xc7,
    0x57, 0x9a, 0x12, 0x25, 0x09, 0x71, 0x12, 0x87, 0x7b, 0x1c, 0xf8, 0x26,
    0x89, 0x93, 0xe0, 0x6d, 0xb4, 0xc2, 0x7b, 0x4f, 0x59, 0x55, 0x0c, 0x7a,
    0x7d, 0xd6, 0x2f, 0x77, 0xe8, 0x9c, 0x3e, 0x7d, 0x64, 0xed, 0xc1, 0xdf,
    0xf9, 0x80, 0x2f, 0x7a, 0xe5, 0x75, 0x05, 0xc0, 0x14, 0xe4, 0xbd, 0x65,
    0x3e, 0xeb, 0xf1, 0xd3, 0x45, 0x9e, 0xff, 0xe8, 0x70, 0x34, 0xa0, 0xd7,
    0xef, 0xd1, 0xed, 0x76, 0xe9, 0xac, 0x75, 0x59, 0x5b, 0x1e, 0xb0, 0x7e,
    0xb1, 0x62, 0xfd, 0x1c, 0x47, 0x97, 0x9f, 0xf7, 0x6f, 0x5f, 0x3e, 0xca,
    0xd5, 0x43, 0x54, 0x53, 0x54, 0xe8, 0xe6, 0xff, 0xf5, 0xf1, 0xc4, 0xdf,
    0x95, 0x71, 0xda, 0x88, 0xd2, 0xb4, 0x06, 0x21, 0xec, 0x74, 0x14, 0x27,
    0x44, 0x51, 0x4c, 0xa4, 0x23, 0xa2, 0x28, 0x42, 0xeb, 0x08, 0xa5, 0xc3,
    0x49, 0xb5, 0x36, 0x1c, 0xc3, 0x7e, 0xbf, 0xcf, 0xfa, 0xea, 0x3a, 0xab,
    0xa7, 0xcf, 0x76, 0xd6, 0x9f, 0x7e, 0xe4, 0x27, 0xcb, 0x13, 0x8f, 0x5e,
    0x73, 0x76, 0xe8, 0x15, 0x03, 0x30, 0xbb, 0x87, 0xdd, 0x07, 0xee, 0x9f,
    0xf8, 0x17, 0xcd, 0x59, 0xfd, 0x5e, 0x15, 0xa5, 0xed, 0x6a, 0x10, 0x31,
    0x58, 0xf3, 0x0c, 0xd6, 0x1c, 0xc3, 0x35, 0x28, 0xfa, 0x31, 0xde, 0x66,
    0xc4, 0xad, 0x68, 0x6a, 0x7a, 0x31, 0xba, 0x77, 0x62, 0x91, 0xaa, 0x77,
    0xc9, 0x1d, 0xb5, 0x25, 0xd5, 0x77, 0xce, 0xe5, 0xd7, 0x4f, 0xaf, 0x78,
    0xd5, 0xfc, 0xaa, 0x53, 0xad, 0xf7, 0x88, 0x38, 0x6d, 0x28, 0x1d, 0x21,
    0x75, 0xcd, 0x03, 0xb2, 0xf6, 0xff, 0x02, 0xc0, 0xe3, 0xbd, 0xc3, 0x1a,
    0x4b, 0x59, 0x16, 0x0c, 0x87, 0x43, 0x7a, 0xdd, 0x1e, 0x9d, 0xe5, 0x35,
    0x2e, 0x9f, 0x7c, 0x71, 0xad, 0xf3, 0xd4, 0x23, 0xef, 0x19, 0x3e, 0xfe,
    0xb9, 0xc7, 0xae, 0x75, 0xf1, 0xf0, 0x0a, 0x52, 0x62, 0xcd, 0x39, 0xa6,
    0x6e, 0xbf, 0xbf, 0xf1, 0x6f, 0xf6, 0xdd, 0xb9, 0xf4, 0x8f, 0x3a, 0x9d,
    0x6e, 0x92, 0x66, 0x09, 0x4b, 0x8b, 0x3b, 0x48, 0xd3, 0x36, 0x65, 0xee,
    0xc9, 0x87, 0x21, 0xb2, 0x53, 0x5a, 0xa2, 0xb4, 0xa7, 0xac, 0x86, 0xac,
    0x5c, 0xbe, 0x08, 0xc2, 0xd3, 0xbd, 0x3c, 0x3c, 0x79, 0xec, 0x89, 0x95,
    0x5f, 0x7c, 0xfe, 0x01, 0xf7, 0x7b, 0x57, 0x7d, 0xf8, 0xd2, 0xdd, 0x37,
    0x45, 0xdb, 0x5f, 0xff, 0x99, 0xe6, 0xd2, 0xce, 0x37, 0x35, 0xe7, 0xa7,
    0x69, 0x4c, 0x34, 0x49, 0x1a, 0x19, 0x51, 0x12, 0xa1, 0xc7, 0x5e, 0x45,
    0x4a, 0x9c, 0xb3, 0x98, 0xb2, 0x22, 0x1f, 0x16, 0x0c, 0x3b, 0x3d, 0xba,
    0x67, 0x5e, 0x7c, 0xac, 0x7f, 0xf4, 0xd1, 0x9f, 0x2d, 0x9f, 0xf9, 0x3f,
    0xd7, 0xe4, 0xfa, 0x36, 0x8f, 0x97, 0xd5, 0x01, 0x37, 0xbe, 0x99, 0x7b,
    0x6f, 0x79, 0xcb, 0xdc, 0x67, 0xee, 0xbc, 0x7b, 0xff, 0xf6, 0xa3, 0x4f,
    0xbf, 0x40, 0x7b, 0x2a, 0x63, 0xdf, 0xbe, 0x9b, 0xd9, 0xba, 0x75, 0x1b,
    0x69, 0xdc, 0xc0, 0x7b, 0xb0, 0xc6, 0x61, 0x5d, 0xf0, 0xf3, 0xde, 0x59,
    0xca, 0xaa, 0x60, 0x75, 0x6d, 0x86, 0x13, 0x27, 0x8f, 0xb3, 0x75, 0x71,
    0x76, 0xd7, 0xae, 0x7d, 0x0b, 0xbf, 0x3b, 0xb3, 0xed, 0x85, 0xbf, 0xfd,
    0xcc, 0x97, 0x47, 0x1f, 0xe8, 0x5f, 0xe2, 0xa5, 0x62, 0xe5, 0xf2, 0xb3,
    0xe7, 0x44, 0xd2, 0xf8, 0xaf, 0x45, 0x5e, 0xec, 0x2b, 0x96, 0xa7, 0x67,
    0xba, 0x93, 0x93, 0x24, 0xed, 0x26, 0x71, 0x23, 0x45, 0xc7, 0x31, 0x52,
    0x2b, 0x3c, 0x1e, 0x5b, 0x5a, 0x8a, 0xc1, 0x88, 0xe2, 0xf2, 0x1a, 0xee,
    0xfc, 0x19, 0x6b, 0x7b, 0x97, 0xbe, 0x6e, 0xd7, 0x8e, 0x5d, 0x53, 0x32,
    0xe7, 0x3b, 0xc7, 0xf7, 0xb4, 0x80, 0x9b, 0xee, 0x11, 0x1f, 0x3c, 0xf0,
    0xf6, 0x2d, 0xbf, 0x7e, 0xe0, 0xae, 0x5b, 0xa3, 0xe7, 0x9e, 0x3e, 0x41,
    0x61, 0x87, 0xdc, 0x71, 0xc7, 0xed, 0xec, 0xdc, 0xb5, 0x8b, 0xa9, 0xc9,
    0x29, 0x94, 0xd4, 0x38, 0xc0, 0xd9, 0xb1, 0x03, 0x07, 0x84, 0xc0, 0x7b,
    0xcb, 0x70, 0x38, 0xe4, 0xfc, 0xf9, 0xb3, 0x1c, 0x3e, 0x7c, 0x84, 0xc5,
    0xc5, 0x6d, 0x78, 0xef, 0xf8, 0xfa, 0x57, 0x0f, 0x1d, 0x7b, 0xe6, 0xcf,
    0xd7, 0xdf, 0x71, 0xe1, 0x30, 0xc7, 0xe5, 0xdc, 0xde, 0xa5, 0x74, 0xef,
    0x3d, 0xff, 0x24, 0x9b, 0x5f, 0xfa, 0xa0, 0x8a, 0xb3, 0xd9, 0x08, 0x87,
    0x36, 0x05, 0x55, 0xaf, 0x47, 0x3e, 0xca, 0xa9, 0xbc, 0xc4, 0x2b, 0x05,
    0x42, 0x22, 0x9c, 0x45, 0x56, 0x25, 0xca, 0x94, 0x28, 0x29, 0xf0, 0x49,
    0x82, 0x53, 0x31, 0x24, 0x89, 0x2f, 0x07, 0x9d, 0x83, 0xc5, 0xca, 0xa9,
    0x7f, 0x5f, 0x1d, 0x7b, 0xe0, 0x4f, 0xb1, 0xa5, 0x79, 0xcd, 0x00, 0xb8,
    0xf1, 0xad, 0x7c, 0xe8, 0xd6, 0x7b, 0x66, 0x7e, 0xf3, 0xc0, 0x9d, 0xfb,
    0xc5, 0xa5, 0xf3, 0x97, 0x39, 0x75, 0xea, 0x14, 0xb7, 0x1e, 0xb8, 0x99,
    0x9b, 0x6f, 0xbe, 0x99, 0x2d, 0x5b, 0xb6, 0x90, 0xa6, 0x19, 0x4a, 0xaa,
    0xa0, 0xef, 0x7c, 0x98, 0x45, 0x20, 0x10, 0x32, 0x64, 0x35, 0x8c, 0x31,
    0x74, 0xd6, 0x3b, 0x9c, 0x38, 0x71, 0x82, 0x23, 0x87, 0x8f, 0xb0, 0x6f,
    0xdf, 0xeb, 0xf0, 0xce, 0xf2, 0xd0, 0x97, 0x9e, 0x3e, 0x75, 0xf0, 0xc9,
    0xf7, 0x7c, 0xae, 0xb5, 0x73, 0xff, 0xcf, 0x6d, 0xd9, 0xb3, 0xb7, 0xd9,
    0xbb, 0x74, 0x91, 0x48, 0x43, 0xab, 0x95, 0xd2, 0xd0, 0x0a, 0x6d, 0x2c,
    0x3e, 0x1f, 0x61, 0xfa, 0x03, 0xaa, 0xd1, 0x08, 0x53, 0x85, 0xb8, 0xdf,
    0x2a, 0x89, 0x97, 0x0a, 0x23, 0xa0, 0xb4, 0x8e, 0xb2, 0xb4, 0x94, 0x45,
    0x45, 0x3a, 0x3b, 0x87, 0x43, 0xb0, 0x7e, 0xea, 0x85, 0x6f, 0x15, 0xe7,
    0x9f, 0xfb, 0x45, 0xf3, 0xec, 0x9f, 0xbd, 0x6a, 0x2d, 0xf0, 0x5d, 0x00,
    0x2c, 0xde, 0xc1, 0x3d, 0x7b, 0xde, 0x9c, 0x7c, 0xf1, 0x8e, 0x1f, 0x7d,
    0x5d, 0x82, 0x17, 0x3c, 0xf1, 0xd8, 0x11, 0x96, 0x6e, 0x9c, 0x67, 0xff,
    0xfe, 0x5b, 0xd8, 0xb9, 0x73, 0x27, 0x53, 0x53, 0x53, 0x44, 0x3a, 0x0a,
    0x5a, 0x5d, 0x88, 0x10, 0x2c, 0xc8, 0xa0, 0xd8, 0x44, 0x40, 0x02, 0xe7,
    0x3c, 0xf9, 0x28, 0x67, 0x79, 0xe5, 0x12, 0x47, 0x8e, 0x1c, 0xe1, 0xfc,
    0xb9, 0x33, 0xc8, 0xe4, 0x6d, 0x3c, 0xf0, 0xed, 0xbb, 0x98, 0xde, 0x7b,
    0x17, 0x8b, 0x37, 0x6c, 0xe5, 0xf9, 0x47, 0x1f, 0x27, 0x69, 0xa7, 0xcc,
    0xcd, 0x4f, 0x33, 0xdd, 0x6c, 0xd2, 0x88, 0x34, 0x91, 0x73, 0x78, 0x53,
    0x62, 0xcb, 0x92, 0xaa, 0xac, 0x30, 0x65, 0x85, 0xb1, 0x96, 0xd2, 0x5a,
    0x4a, 0x67, 0x29, 0x8d, 0x65, 0x54, 0x95, 0x8c, 0x46, 0x25, 0xc3, 0xfe,
    0x88, 0x51, 0x6f, 0xc8, 0xc4, 0xe2, 0x36, 0xa2, 0x89, 0x09, 0x56, 0x9e,
    0x3f, 0xee, 0xfb, 0xa7, 0x8f, 0xfe, 0x51, 0xf1, 0xfc, 0xc3, 0x1f, 0xf6,
    0xcb, 0x47, 0x5e, 0x71, 0x7e, 0xf0, 0x25, 0x5e, 0x20, 0x9d, 0x64, 0x62,
    0xfb, 0x5d, 0xf2, 0xcf, 0x76, 0xed, 0x9f, 0x9b, 0x6f, 0x36, 0x9b, 0x1c,
    0x7d, 0xea, 0x04, 0x48, 0xc7, 0xc2, 0xb6, 0x39, 0xe6, 0xe7, 0xe7, 0x69,
    0x36, 0x9b, 0x81, 0x98, 0xc6, 0x0c, 0x5d, 0x87, 0xaa, 0x1b, 0x32, 0xb6,
    0xd6, 0xfc, 0x3e, 0x04, 0xf3, 0x00, 0x94, 0xa5, 0xe3, 0x8b, 0x5f, 0xbb,
    0x8d, 0x17, 0x46, 0x7f, 0x93, 0x9b, 0xdf, 0xfa, 0xe3, 0xec, 0xd9, 0xb9,
    0x95, 0x43, 0x0f, 0x3d, 0x4c, 0x32, 0xd9, 0x60, 0xdb, 0x8e, 0x45, 0x16,
    0x17, 0x16, 0x58, 0x98, 0x9f, 0x61, 0x66, 0xaa, 0xcd, 0xc4, 0x44, 0x83,
    0x66, 0xbb, 0x49, 0xab, 0xdd, 0xa4, 0xd1, 0x6a, 0xd1, 0x9c, 0x68, 0xd1,
    0x98, 0x9c, 0x20, 0x9b, 0x9c, 0x20, 0x6b, 0xb7, 0x89, 0x9a, 0x4d, 0xa2,
    0x46, 0x03, 0x99, 0xc5, 0x08, 0xad, 0x41, 0x49, 0xfa, 0x2b, 0x1d, 0x1a,
    0xad, 0x06, 0x33, 0x7b, 0x76, 0x0a, 0x1f, 0xb5, 0x6e, 0x71, 0xe9, 0x96,
    0xbf, 0xef, 0xe2, 0xa9, 0xe7, 0xdc, 0xca, 0xf3, 0xaf, 0x88, 0x20, 0x5f,
    0x42, 0x24, 0xdb, 0x6e, 0x17, 0xff, 0x74, 0x6a, 0x51, 0xed, 0x6e, 0x36,
    0x1b, 0x2c, 0x2f, 0xaf, 0xd0, 0x59, 0x19, 0x32, 0xb3, 0x98, 0xa2, 0xb4,
    0xc2, 0x58, 0xcb, 0x68, 0x34, 0x42, 0x00, 0xc6, 0x9a, 0x3a, 0x8b, 0x23,
    0x6b, 0xad, 0x2e, 0x51, 0x3a, 0xb8, 0xb0, 0xb1, 0x51, 0x79, 0xef, 0xe9,
    0xf5, 0x15, 0x9f, 0xfa, 0xe3, 0x37, 0x92, 0xee, 0x7d, 0x1b, 0x6f, 0xdc,
    0xbf, 0x87, 0xc9, 0x54, 0xf3, 0xd0, 0x9f, 0x7c, 0x11, 0x91, 0x6a, 0x16,
    0x96, 0x16, 0xd8, 0xb6, 0x30, 0xcf, 0x96, 0xe9, 0x29, 0xda, 0x59, 0x4c,
    0x2c, 0x05, 0xc2, 0x3b, 0x9c, 0x73, 0x58, 0x63, 0x82, 0xcc, 0xad, 0x2c,
    0xc6, 0x39, 0x2a, 0xeb, 0x28, 0x8c, 0x23, 0x2d, 0x4b, 0x92, 0x3c, 0x47,
    0x0f, 0x87, 0x88, 0x38, 0x06, 0x25, 0xf1, 0x08, 0x56, 0x4e, 0x9f, 0x61,
    0x6b, 0xaa, 0x99, 0xdf, 0x73, 0x03, 0x3a, 0x89, 0x66, 0x3b, 0x69, 0xe3,
    0xf3, 0xc3, 0xa4, 0xf9, 0x6f, 0xab, 0x27, 0x3e, 0xf7, 0x91, 0x2b, 0x04,
    0xf5, 0x7d, 0x2c, 0x20, 0xca, 0x48, 0x17, 0x0f, 0x88, 0xdf, 0x9d, 0xdb,
    0x9e, 0xb5, 0x1b, 0x8d, 0x8c, 0xb3, 0xc7, 0x57, 0x30, 0x95, 0xa1, 0x35,
    0x15, 0xd3, 0x6c, 0x36, 0x49, 0xd3, 0x14, 0x21, 0x42, 0xae, 0xde, 0x3b,
    0x8f, 0xb5, 0x36, 0x5c, 0xc6, 0x62, 0xad, 0xab, 0x73, 0x77, 0x0e, 0xe7,
    0x2c, 0xce, 0x59, 0x2e, 0x5c, 0x74, 0x7c, 0xf4, 0x93, 0xbb, 0xd8, 0x72,
    0xe7, 0x4f, 0x70, 0xdb, 0xfe, 0x9b, 0x68, 0xc5, 0x82, 0xc7, 0x1e, 0xfc,
    0x2a, 0x9d, 0x6e, 0x8f, 0x85, 0x9d, 0x8b, 0x2c, 0x2d, 0x6e, 0x65, 0xeb,
    0xec, 0x0c, 0x53, 0xad, 0x8c, 0x2c, 0x89, 0x42, 0x94, 0xa7, 0x43, 0x5e,
    0x40, 0x69, 0x1d, 0xc2, 0x63, 0x1d, 0x21, 0xa3, 0x18, 0x19, 0x45, 0xe1,
    0xb3, 0xd2, 0x08, 0x25, 0xf1, 0x42, 0xd4, 0xf6, 0x17, 0x3c, 0x90, 0x73,
    0x8e, 0xb5, 0xb3, 0xcb, 0x4c, 0xcc, 0xb4, 0x48, 0xdb, 0x4d, 0x64, 0x92,
    0x0a, 0xa7, 0x1a, 0xf7, 0xba, 0xc6, 0xc2, 0x9c, 0xbd, 0xf0, 0xcc, 0x17,
    0x5e, 0x0e, 0x84, 0x0d, 0x00, 0xb6, 0xee, 0x17, 0x3f, 0x31, 0xbf, 0x57,
    0xfc, 0xdc, 0xd4, 0x6c, 0x13, 0xe7, 0x2c, 0xe7, 0x8f, 0xf7, 0xd0, 0x89,
    0x20, 0x6d, 0x47, 0x64, 0x59, 0x86, 0xd6, 0x7a, 0x63, 0x67, 0x9d, 0xab,
    0x77, 0xca, 0x5a, 0x9c, 0xb5, 0x18, 0x6b, 0xeb, 0xcf, 0x21, 0x6d, 0x7d,
    0x69, 0xd9, 0xf1, 0x1f, 0x7f, 0x7b, 0x17, 0x8b, 0x6f, 0xb8, 0x97, 0x9b,
    0xf7, 0xec, 0x40, 0xf9, 0x92, 0xe7, 0x9f, 0x79, 0x9a, 0x63, 0x4f, 0x1f,
    0x65, 0x76, 0xfb, 0x36, 0x96, 0xb6, 0x6f, 0x63, 0x61, 0x6e, 0x96, 0xa9,
    0x76, 0xb3, 0xae, 0x0b, 0x8c, 0xf9, 0x44, 0xd6, 0xb9, 0x0f, 0x81, 0x47,
    0xe0, 0x65, 0x58, 0xac, 0x13, 0x02, 0xe7, 0x05, 0x0e, 0xb0, 0xae, 0x4e,
    0x9a, 0x7a, 0x87, 0xf5, 0xe1, 0xf9, 0xce, 0x7a, 0x9c, 0xb5, 0xf4, 0x96,
    0x3b, 0xb4, 0xe6, 0x26, 0x88, 0xd2, 0x04, 0x19, 0x47, 0xa0, 0xb2, 0x1f,
    0x73, 0xd9, 0xd6, 0xb6, 0x3d, 0xff, 0xd4, 0x97, 0xbe, 0x2f, 0x00, 0xdb,
    0xef, 0x12, 0xbf, 0x30, 0xb5, 0xa4, 0xdf, 0xd0, 0x6a, 0x35, 0xe9, 0xad,
    0x0f, 0xe9, 0x5c, 0xac, 0x48, 0x9a, 0x9e, 0xb8, 0x21, 0x89, 0xe3, 0x38,
    0x64, 0x6c, 0x10, 0x75, 0xb2, 0xd2, 0x6d, 0x58, 0x80, 0xa9, 0x73, 0xf5,
    0xc6, 0x58, 0xac, 0x35, 0x0c, 0x87, 0x86, 0x8f, 0x7d, 0x6a, 0x17, 0xb3,
    0xb7, 0xbf, 0x8d, 0xbd, 0x37, 0x6e, 0x47, 0xf9, 0x8a, 0xb3, 0x67, 0x5f,
    0xe4, 0xdb, 0x0f, 0x1c, 0xa4, 0x39, 0x37, 0xcd, 0x96, 0x1d, 0xdb, 0xd8,
    0xba, 0xb0, 0x85, 0x99, 0x89, 0x09, 0xd2, 0x38, 0x0a, 0xb5, 0x01, 0x01,
    0xce, 0x07, 0x70, 0xad, 0x1f, 0xd7, 0x04, 0xc2, 0xef, 0x8c, 0x0b, 0xf5,
    0x41, 0xeb, 0x42, 0x7a, 0xdc, 0x58, 0x8b, 0xb1, 0x26, 0x58, 0x9b, 0xb5,
    0x38, 0x3f, 0xde, 0x08, 0x4f, 0x35, 0x2a, 0x30, 0x79, 0x41, 0x63, 0xb2,
    0x85, 0x4e, 0x62, 0x84, 0x52, 0x78, 0x99, 0xbe, 0xc9, 0xc6, 0x33, 0x3d,
    0x7b, 0xf1, 0xc8, 0xc1, 0x97, 0xe5, 0x80, 0x28, 0xe3, 0xd6, 0x46, 0x33,
    0x05, 0xa0, 0xbf, 0x56, 0x8c, 0x93, 0x4f, 0x38, 0xeb, 0x28, 0xcb, 0x92,
    0x7c, 0x34, 0x42, 0x0a, 0x81, 0x17, 0xf5, 0x8b, 0xd6, 0x8b, 0x97, 0x4a,
    0xa1, 0x95, 0x44, 0x4a, 0x45, 0x14, 0x49, 0x3e, 0xfb, 0xc7, 0xbb, 0x51,
    0xdb, 0x5e, 0xcf, 0x8e, 0xed, 0xdb, 0x90, 0xbe, 0xe2, 0xd2, 0xf2, 0x25,
    0x8e, 0x7c, 0xfd, 0x5b, 0x20, 0x04, 0xad, 0xe9, 0x36, 0x93, 0x13, 0x6d,
    0x9a, 0x69, 0x8a, 0x56, 0x41, 0xdf, 0x1b, 0xe7, 0x11, 0x6e, 0x73, 0x5d,
    0x00, 0xfc, 0xb8, 0x14, 0xe6, 0x3c, 0xd6, 0x38, 0x2a, 0x53, 0x67, 0xa1,
    0xad, 0xc1, 0x38, 0x8b, 0x75, 0xc1, 0xfc, 0x85, 0x10, 0x28, 0xad, 0x89,
    0x93, 0x98, 0x2a, 0x8b, 0x31, 0x45, 0xc2, 0x60, 0xad, 0x4f, 0x63, 0xaa,
    0x45, 0xd2, 0x6e, 0xd1, 0x98, 0x6c, 0x63, 0x2b, 0x83, 0xc9, 0xf7, 0xfd,
    0x8a, 0x1d, 0xbc, 0xfd, 0x11, 0xfb, 0xc2, 0x83, 0x5f, 0xff, 0x9e, 0x00,
    0x64, 0x13, 0x6a, 0x77, 0xb3, 0xd9, 0xc4, 0x5a, 0xc3, 0xa8, 0xeb, 0x10,
    0x0a, 0xf0, 0x1e, 0x67, 0x1d, 0x55, 0x55, 0x52, 0x14, 0x05, 0x4a, 0xa9,
    0x3a, 0x13, 0xe3, 0x37, 0x40, 0xd0, 0x5a, 0x63, 0x6a, 0x22, 0x7c, 0xea,
    0xf0, 0x34, 0x27, 0xd6, 0x6f, 0xe6, 0xd6, 0x03, 0x4b, 0x68, 0xe1, 0xe8,
    0x74, 0xba, 0x9c, 0x3d, 0x75, 0x8a, 0xd5, 0x17, 0xcf, 0x33, 0xb9, 0xb4,
    0x95, 0xd6, 0x44, 0x9b, 0x46, 0x96, 0x12, 0x69, 0x85, 0xf3, 0x50, 0x59,
    0x87, 0xf2, 0x57, 0x3c, 0xf1, 0xd8, 0x0a, 0x9c, 0x73, 0x58, 0xef, 0xeb,
    0xd2, 0x58, 0xb0, 0x2e, 0x63, 0x4c, 0x0d, 0x44, 0xb0, 0x3c, 0xe7, 0x42,
    0x72, 0x54, 0x08, 0x89, 0xd2, 0x1a, 0x1d, 0x47, 0x44, 0x59, 0x82, 0x29,
    0x2a, 0xd6, 0x2f, 0xac, 0x32, 0xd7, 0x48, 0x89, 0xd2, 0x98, 0xc6, 0x54,
    0x9b, 0x6a, 0x34, 0x9f, 0x98, 0xfe, 0xfe, 0xff, 0x36, 0x3c, 0xf3, 0xad,
    0x1f, 0x23, 0x5f, 0x1f, 0x6d, 0x06, 0x60, 0x23, 0x21, 0x12, 0x67, 0x7a,
    0xaa, 0xd5, 0x6a, 0xa1, 0x94, 0xc2, 0xe4, 0x1e, 0x21, 0x83, 0x05, 0x58,
    0xe7, 0x31, 0x95, 0xa5, 0x2c, 0x03, 0x08, 0x45, 0x51, 0x90, 0xe7, 0x39,
    0x79, 0x9e, 0x6f, 0xfc, 0x5c, 0x14, 0x05, 0x83, 0x61, 0xc1, 0x97, 0x1f,
    0xd9, 0xcb, 0x96, 0xdd, 0x4b, 0x34, 0x92, 0x88, 0x3c, 0x1f, 0x70, 0x79,
    0xe5, 0x12, 0x67, 0x0f, 0xbf, 0x80, 0x8a, 0x22, 0xd2, 0x76, 0x83, 0xac,
    0x19, 0xb2, 0xc8, 0xd6, 0x39, 0xaa, 0xca, 0x50, 0x54, 0x86, 0xbc, 0x30,
    0xe4, 0xa5, 0x21, 0xaf, 0x3f, 0x87, 0xcb, 0x52, 0x56, 0x06, 0x53, 0x5f,
    0x95, 0x35, 0x54, 0x9b, 0x80, 0xb0, 0x36, 0xa4, 0xc6, 0xbd, 0x0b, 0xee,
    0x56, 0x08, 0xd0, 0x91, 0x26, 0x4a, 0x02, 0x08, 0xc5, 0x30, 0x67, 0xb4,
    0xde, 0x47, 0x4a, 0x48, 0x1a, 0x29, 0x8d, 0xa9, 0x49, 0xd2, 0xf9, 0x6d,
    0xb7, 0x45, 0xb7, 0xdc, 0xff, 0xe1, 0xef, 0x69, 0x01, 0xc5, 0xc0, 0xad,
    0xa4, 0x69, 0xda, 0x2c, 0xcb, 0x02, 0xe7, 0x40, 0x6f, 0xca, 0xd1, 0x5b,
    0x67, 0xa9, 0x8c, 0x41, 0x57, 0xd5, 0x26, 0x57, 0x17, 0x76, 0x4a, 0x29,
    0x85, 0xd2, 0x92, 0xa7, 0x9e, 0xd9, 0x81, 0xcb, 0x96, 0x68, 0x4d, 0xb5,
    0xf0, 0xb6, 0xa4, 0xdf, 0x1f, 0xb2, 0x76, 0x71, 0x99, 0xfe, 0xa5, 0x55,
    0x5a, 0xf3, 0xb3, 0x24, 0x75, 0xfa, 0xdb, 0x7b, 0xa8, 0x8c, 0x41, 0x0a,
    0x81, 0x74, 0x81, 0x57, 0xc4, 0x38, 0x05, 0x5e, 0x1f, 0x83, 0x71, 0x89,
    0xcc, 0xd7, 0xc4, 0x6a, 0x9c, 0xad, 0xcf, 0xbe, 0x0d, 0x47, 0xc0, 0xda,
    0x9a, 0x0c, 0x5d, 0x20, 0x78, 0x01, 0x52, 0xc9, 0x1a, 0x84, 0x98, 0x28,
    0x4b, 0xe8, 0xaf, 0x74, 0xc8, 0x26, 0x9a, 0x44, 0x49, 0x12, 0xc0, 0x9f,
    0x9e, 0xa2, 0x9c, 0xbd, 0xe1, 0x17, 0xcc, 0xc4, 0xd2, 0x27, 0x7d, 0xf7,
    0x6c, 0xe7, 0xbb, 0x48, 0xb0, 0x35, 0xef, 0xa6, 0x92, 0x49, 0x73, 0x6f,
    0x55, 0x19, 0x2e, 0x9f, 0x1d, 0x11, 0x25, 0x02, 0x95, 0x82, 0x8a, 0x40,
    0x2a, 0xb1, 0xe1, 0xf3, 0x43, 0x76, 0x98, 0xba, 0x8c, 0x55, 0x9b, 0xab,
    0xf5, 0x3c, 0xf4, 0x8d, 0x37, 0xd0, 0xbe, 0x61, 0x17, 0x93, 0x33, 0x53,
    0x08, 0xef, 0xe9, 0xad, 0x77, 0xb8, 0x70, 0xf4, 0x04, 0xe5, 0x60, 0x44,
    0x73, 0x66, 0x92, 0xf6, 0xdc, 0x14, 0xcd, 0x76, 0x8b, 0x28, 0xd2, 0x08,
    0x21, 0x83, 0xb9, 0xbb, 0xda, 0x7d, 0xd6, 0xc4, 0xea, 0x6b, 0x97, 0x66,
    0x09, 0xae, 0xd4, 0x3a, 0x87, 0xdd, 0x58, 0x7c, 0x38, 0x02, 0x63, 0xd7,
    0xbb, 0x41, 0xbe, 0xd6, 0xe0, 0xac, 0xc5, 0xbb, 0x80, 0x5d, 0xa8, 0x1d,
    0x78, 0x8a, 0x7e, 0x4e, 0x94, 0xc5, 0x24, 0xcd, 0x0c, 0xa9, 0x35, 0xde,
    0x83, 0xa9, 0x7c, 0xd3, 0x38, 0x75, 0xda, 0x5e, 0x38, 0xfc, 0xf8, 0x77,
    0x01, 0xb0, 0x7e, 0x96, 0x83, 0x56, 0xe6, 0x4b, 0x83, 0xf5, 0xd1, 0x1d,
    0xce, 0x08, 0x11, 0x65, 0xa0, 0xe3, 0x2b, 0x00, 0x8c, 0xcf, 0xff, 0x18,
    0x84, 0xf1, 0xf0, 0xde, 0x71, 0xe1, 0xe2, 0x34, 0xc7, 0x2e, 0xfe, 0x08,
    0xd3, 0x37, 0x2c, 0xd0, 0x68, 0xa5, 0x58, 0x5b, 0xd1, 0xbd, 0xbc, 0xc6,
    0x85, 0x23, 0xc7, 0x50, 0x71, 0x4c, 0x63, 0x7a, 0x82, 0xc6, 0x64, 0x9b,
    0x38, 0x4b, 0x91, 0x4a, 0xd7, 0x41, 0x13, 0xc1, 0xa3, 0xd4, 0x25, 0x30,
    0xeb, 0x6a, 0x46, 0x1f, 0xbb, 0xd8, 0xba, 0x08, 0x62, 0xad, 0xaf, 0x41,
    0x18, 0x6b, 0x0d, 0x53, 0x6b, 0x8f, 0x7a, 0xf1, 0x2e, 0x58, 0x8a, 0xaf,
    0x8b, 0x28, 0xf8, 0x9a, 0x44, 0x2b, 0x8b, 0x33, 0x15, 0x8d, 0x89, 0x26,
    0x51, 0x12, 0x23, 0x65, 0x10, 0x73, 0xe5, 0x60, 0xb8, 0x58, 0x9d, 0x7c,
    0xec, 0x93, 0xdf, 0xc5, 0x01, 0xa6, 0xa0, 0x78, 0xee, 0xcb, 0xfe, 0x1f,
    0x3c, 0xf7, 0x15, 0xbf, 0xd7, 0x3b, 0xdf, 0x1d, 0x8b, 0x59, 0x5f, 0x4f,
    0xb8, 0xe1, 0xfb, 0x9d, 0xc5, 0xd6, 0x75, 0xc1, 0xaa, 0xaa, 0x30, 0xa6,
    0xe4, 0xd8, 0xa9, 0x25, 0xd2, 0x76, 0x86, 0x8e, 0x24, 0xce, 0x1a, 0x8a,
    0xd1, 0x88, 0xfe, 0xe5, 0x35, 0xaa, 0xe1, 0x08, 0x15, 0x29, 0x44, 0x5d,
    0x34, 0x35, 0x65, 0x41, 0x59, 0x16, 0x14, 0x45, 0x4e, 0x51, 0xe4, 0xe4,
    0x65, 0x49, 0x51, 0x96, 0x14, 0x55, 0x49, 0x59, 0x19, 0x4a, 0x53, 0x51,
    0x19, 0x43, 0x39, 0x26, 0x3c, 0x67, 0x31, 0xae, 0x76, 0x79, 0xf5, 0xb3,
    0x9d, 0xf3, 0x63, 0x11, 0x0e, 0x48, 0xa4, 0x90, 0x88, 0xba, 0x96, 0x20,
    0xa5, 0x42, 0x69, 0x45, 0x94, 0x26, 0xc4, 0xcd, 0x06, 0xa6, 0x74, 0x94,
    0xa3, 0x1c, 0x21, 0x05, 0x49, 0x23, 0xa5, 0x39, 0x3d, 0x45, 0x32, 0xbb,
    0xed, 0x80, 0x9c, 0xdb, 0x7d, 0xe3, 0x77, 0x59, 0xc0, 0x78, 0x54, 0x39,
    0xdd, 0xd6, 0x82, 0xd8, 0x93, 0xb5, 0xc5, 0x9d, 0x2a, 0x06, 0xa9, 0x41,
    0x28, 0xea, 0x23, 0x50, 0x97, 0xae, 0xc4, 0xa6, 0x73, 0xeb, 0x3d, 0x87,
    0x9e, 0xbb, 0x9b, 0x64, 0x6a, 0x81, 0xe6, 0x74, 0x1b, 0x1d, 0x29, 0xf2,
    0xc1, 0x90, 0x95, 0x63, 0xa7, 0xa9, 0x86, 0x23, 0x92, 0x56, 0x83, 0xa4,
    0x99, 0x11, 0xa7, 0x71, 0x28, 0x62, 0x08, 0x39, 0xae, 0x12, 0x6c, 0x94,
    0xbc, 0xc6, 0xd6, 0xe0, 0x5d, 0xe8, 0x0b, 0x7a, 0xa9, 0x65, 0xf8, 0x2b,
    0x16, 0x62, 0xc7, 0xcd, 0x13, 0xbe, 0x2e, 0x91, 0xf9, 0x8d, 0x54, 0xfa,
    0x95, 0x8a, 0x9a, 0x0c, 0x85, 0x12, 0x29, 0x71, 0x16, 0x84, 0x37, 0x64,
    0x13, 0x2d, 0xa2, 0x38, 0xc4, 0x0f, 0xc5, 0xb0, 0x90, 0x65, 0xee, 0x0e,
    0x9b, 0x73, 0x4f, 0x7d, 0xf3, 0xaa, 0x00, 0x00, 0xaa, 0x7b, 0x96, 0x87,
    0xb2, 0x69, 0x3f, 0x8a, 0x52, 0x6e, 0x51, 0xb1, 0x68, 0x09, 0x09, 0x42,
    0xd4, 0x71, 0x6f, 0x6d, 0x15, 0xe3, 0xc2, 0x65, 0x9e, 0xc7, 0x1c, 0x3f,
    0xf7, 0x26, 0x9a, 0xb3, 0xd3, 0x34, 0xda, 0x4d, 0xa4, 0x14, 0x0c, 0xd7,
    0xfb, 0x2c, 0x1f, 0x3d, 0x0e, 0x52, 0x12, 0x37, 0x32, 0xa2, 0x2c, 0xad,
    0xa5, 0x6c, 0x28, 0x80, 0x0a, 0x21, 0x02, 0x08, 0xa1, 0x3f, 0x22, 0x58,
    0x9a, 0x73, 0x78, 0x7f, 0x45, 0x68, 0xf9, 0xba, 0x49, 0x6a, 0xdc, 0x22,
    0xe3, 0x09, 0x80, 0x8c, 0xa5, 0x78, 0x28, 0xa0, 0x06, 0xde, 0x18, 0x7b,
    0x52, 0xa9, 0xea, 0xca, 0x92, 0x0a, 0x95, 0x23, 0x2f, 0x24, 0x66, 0x34,
    0x24, 0x6b, 0x87, 0x4c, 0x93, 0x8e, 0x12, 0xca, 0xb2, 0x62, 0xb8, 0xb2,
    0xdc, 0x29, 0x4f, 0x3e, 0xf6, 0x47, 0x2f, 0xf1, 0x02, 0x9b, 0x86, 0x77,
    0x8e, 0xf2, 0xf8, 0xc3, 0xfc, 0x86, 0x4a, 0xfc, 0xef, 0x6d, 0xbd, 0xd9,
    0xbf, 0x65, 0x66, 0xb7, 0xb8, 0x37, 0x69, 0xda, 0xbb, 0xb2, 0x49, 0xbf,
    0x33, 0xce, 0x54, 0x4b, 0x6b, 0x27, 0xac, 0x0d, 0xa4, 0xd8, 0x1f, 0x4c,
    0x20, 0x55, 0x08, 0x98, 0x10, 0x60, 0x8c, 0x25, 0xef, 0x0f, 0x29, 0x47,
    0x23, 0xe2, 0x66, 0x03, 0x00, 0x67, 0x2d, 0xb6, 0x32, 0x54, 0x65, 0x89,
    0xd4, 0x12, 0x21, 0xd5, 0xc6, 0xe1, 0x73, 0x3a, 0x2c, 0x44, 0x2a, 0x85,
    0x74, 0xc1, 0xda, 0x04, 0xb2, 0x06, 0xbc, 0x06, 0xa9, 0x76, 0x11, 0x42,
    0x0a, 0xbc, 0x23, 0x58, 0xa0, 0x14, 0x08, 0x2f, 0x91, 0x75, 0x73, 0xc5,
    0x38, 0x4e, 0x51, 0x80, 0xd2, 0x1e, 0x2f, 0x24, 0xd6, 0x49, 0xcc, 0x68,
    0x80, 0x29, 0x4a, 0x04, 0x90, 0x24, 0x31, 0x8d, 0xa9, 0x09, 0x74, 0x92,
    0xdc, 0x34, 0x5e, 0xec, 0xd5, 0x00, 0x70, 0x78, 0x4a, 0x0f, 0xc2, 0x16,
    0x70, 0xf6, 0x49, 0xbe, 0x72, 0xee, 0x90, 0x7f, 0x18, 0x41, 0x2c, 0x95,
    0x6d, 0xa4, 0x93, 0x6e, 0x6b, 0x63, 0xaa, 0xda, 0x92, 0x4d, 0xca, 0xe9,
    0x74, 0x82, 0xc9, 0xa1, 0x7c, 0xdd, 0x1b, 0xd4, 0xac, 0x7a, 0xa7, 0xd4,
    0x81, 0x24, 0xad, 0x35, 0xe4, 0xdd, 0x1e, 0xde, 0xba, 0xa0, 0xeb, 0xbd,
    0xc7, 0x1b, 0x83, 0xad, 0x2a, 0x6c, 0x51, 0x52, 0x8d, 0x13, 0x9f, 0x32,
    0x14, 0x3b, 0x7d, 0x6d, 0x52, 0xca, 0x83, 0x97, 0x20, 0x7c, 0xe8, 0x0c,
    0x43, 0x86, 0x3a, 0xb1, 0xf0, 0x62, 0xe3, 0xc8, 0x88, 0xf0, 0x6b, 0xbc,
    0x08, 0x20, 0x49, 0xa9, 0x41, 0x85, 0xbe, 0x04, 0xb9, 0x29, 0xde, 0xf1,
    0x80, 0x90, 0x0a, 0xe7, 0x25, 0xe5, 0x30, 0xa3, 0xcc, 0x43, 0x1d, 0x32,
    0x8e, 0x63, 0x1a, 0xed, 0x16, 0xba, 0x35, 0xb1, 0xf8, 0x72, 0x00, 0x78,
    0xc0, 0xd4, 0xa1, 0xbe, 0x41, 0x50, 0x00, 0x29, 0x90, 0x38, 0x43, 0x3e,
    0x5c, 0xf5, 0xfd, 0xe1, 0x2a, 0xa7, 0x84, 0xb0, 0x0a, 0xd0, 0xd1, 0x6d,
    0xbb, 0xa6, 0xa7, 0xb6, 0x49, 0xa4, 0x56, 0xa1, 0xdf, 0xa7, 0xaa, 0xc8,
    0xd7, 0x7b, 0x21, 0x3b, 0x24, 0xe4, 0x86, 0x9a, 0xb4, 0xb5, 0xa8, 0x11,
    0x95, 0xa9, 0xa3, 0x3d, 0x13, 0x2c, 0x41, 0xd4, 0xba, 0x42, 0x84, 0x9a,
    0xbf, 0x70, 0x12, 0x70, 0xc1, 0x0a, 0xa4, 0xdc, 0x00, 0x28, 0xbc, 0x58,
    0xcd, 0x3f, 0x52, 0x22, 0x15, 0x78, 0x0b, 0x68, 0x8d, 0xf0, 0x7e, 0xa3,
    0xac, 0x2e, 0xea, 0x4a, 0xb2, 0x52, 0x0e, 0x87, 0xa4, 0x6a, 0xb5, 0x28,
    0xbb, 0xab, 0x78, 0x0f, 0x51, 0xa4, 0x69, 0xb6, 0x5a, 0x44, 0xcd, 0xf6,
    0xd4, 0xcb, 0x01, 0x70, 0x05, 0x04, 0xb0, 0x78, 0x2a, 0xef, 0xc9, 0x11,
    0x68, 0x40, 0x8f, 0xef, 0x3e, 0x6c, 0x86, 0x92, 0x69, 0xcb, 0x2b, 0x1d,
    0x11, 0x25, 0x31, 0x48, 0x19, 0x54, 0xe3, 0x60, 0x50, 0x97, 0xb4, 0x37,
    0x45, 0x8f, 0x75, 0x97, 0x97, 0xdb, 0xe4, 0xcb, 0xa5, 0xb2, 0x48, 0xa9,
    0x70, 0xd2, 0xd5, 0x2d, 0x36, 0x61, 0x19, 0xde, 0xab, 0xfa, 0xee, 0xeb,
    0x79, 0xae, 0xdc, 0xc3, 0xf1, 0x70, 0xc8, 0x3a, 0x96, 0x90, 0x41, 0xb2,
    0x06, 0x6b, 0x11, 0xc1, 0x1b, 0x20, 0x24, 0xda, 0x39, 0xac, 0x87, 0xaa,
    0xed, 0x28, 0x3a, 0x97, 0x11, 0x42, 0x90, 0x26, 0x09, 0x4a, 0xc7, 0xe8,
    0x38, 0x89, 0xbf, 0x1f, 0x00, 0x9b, 0x81, 0xb0, 0x1b, 0x40, 0x04, 0x9b,
    0xdd, 0x28, 0xd6, 0x7b, 0x10, 0x1e, 0x71, 0x41, 0x6a, 0x45, 0xd2, 0xc8,
    0x50, 0xb1, 0x0a, 0xe2, 0x26, 0x2f, 0x36, 0x04, 0x53, 0x8d, 0x42, 0xcd,
    0xf8, 0x0e, 0x3f, 0x6e, 0x72, 0x70, 0x63, 0x12, 0xab, 0x99, 0x9d, 0x3a,
    0xc1, 0xaa, 0x3c, 0x92, 0x40, 0x74, 0xc8, 0x7a, 0x47, 0x6b, 0x4b, 0x0a,
    0x75, 0x44, 0x1f, 0x5a, 0x72, 0xbc, 0x0f, 0x16, 0x34, 0xb6, 0x0d, 0x11,
    0x8a, 0xa8, 0x52, 0x85, 0xbb, 0x75, 0xc1, 0x02, 0x8c, 0x97, 0x74, 0x95,
    0x46, 0xeb, 0x88, 0x46, 0x9a, 0x51, 0x18, 0x8b, 0xb7, 0xd5, 0x46, 0x15,
    0xe9, 0xd5, 0xa4, 0x96, 0xaf, 0xe4, 0xb9, 0x36, 0x8d, 0xea, 0xdc, 0x33,
    0x0f, 0x98, 0x7d, 0x07, 0x48, 0x1a, 0x4d, 0xd2, 0x2c, 0x61, 0xd0, 0xe9,
    0x61, 0xab, 0x97, 0xd6, 0x42, 0x7c, 0x0d, 0x00, 0xee, 0x0a, 0x83, 0x07,
    0x5d, 0x11, 0x40, 0x91, 0xce, 0xe1, 0x9d, 0xc5, 0xc9, 0x7a, 0x61, 0x3e,
    0x40, 0x1b, 0x42, 0xcf, 0x71, 0x7f, 0x44, 0x6d, 0x1d, 0xf2, 0xca, 0x1e,
    0xc8, 0xcd, 0x8b, 0x17, 0xa1, 0x3f, 0x49, 0xd5, 0xfd, 0x04, 0xde, 0x0b,
    0x90, 0x9a, 0xca, 0x82, 0x4e, 0x52, 0xe2, 0x34, 0x94, 0xd8, 0xd6, 0xd6,
    0x57, 0xc8, 0x2f, 0x5f, 0x3c, 0x74, 0x2d, 0x00, 0x5c, 0x75, 0x98, 0x17,
    0xbf, 0xf9, 0xe8, 0xf0, 0xfc, 0x5b, 0xbe, 0xd1, 0xef, 0xec, 0x7d, 0xe3,
    0xc4, 0xd4, 0x34, 0x2a, 0x4e, 0xf0, 0xc6, 0x86, 0x9c, 0xdd, 0xd8, 0x7c,
    0x6b, 0xf8, 0x36, 0xdc, 0x98, 0xad, 0xd5, 0x9b, 0x73, 0xb8, 0xda, 0xf7,
    0x4b, 0x07, 0x7e, 0xec, 0x6a, 0x6b, 0xa5, 0x38, 0x6e, 0x0c, 0x11, 0x75,
    0xd9, 0x1d, 0xea, 0x7e, 0x81, 0x0d, 0xa7, 0x1f, 0x8e, 0x80, 0x90, 0x12,
    0x5d, 0x37, 0x68, 0x69, 0xa5, 0x36, 0x54, 0xab, 0x17, 0x92, 0xdc, 0x38,
    0x74, 0x9c, 0x60, 0x9d, 0x60, 0xb5, 0xd7, 0xe7, 0xf8, 0xe1, 0x67, 0xe9,
    0x9f, 0x7a, 0xee, 0x63, 0xaf, 0x19, 0x00, 0x38, 0xeb, 0x46, 0xcf, 0x7d,
    0xe3, 0x67, 0xce, 0xb4, 0xa6, 0x1e, 0xaa, 0x8a, 0x62, 0xdb, 0xa8, 0xdf,
    0xc5, 0x59, 0x8b, 0x8a, 0xa2, 0x2b, 0x44, 0xb8, 0xe9, 0x85, 0x83, 0x19,
    0x8d, 0x9b, 0xa0, 0x3c, 0x21, 0x03, 0x30, 0x4e, 0xb1, 0x86, 0x45, 0x0b,
    0x7c, 0xf8, 0x9e, 0x08, 0x5f, 0x1a, 0x07, 0x4c, 0x42, 0x08, 0xa4, 0x12,
    0x2f, 0x21, 0x3c, 0x25, 0x25, 0x4a, 0x29, 0xb4, 0x0c, 0xa9, 0xb4, 0x58,
    0xeb, 0x8d, 0x22, 0xaa, 0xf3, 0x82, 0x91, 0x71, 0x78, 0x6b, 0x39, 0x7f,
    0xfa, 0x34, 0xa7, 0x87, 0x39, 0x17, 0x1e, 0xfd, 0xea, 0xc7, 0xf3, 0x27,
    0x3e, 0xff, 0xf9, 0xd7, 0x0e, 0x00, 0xa0, 0x3c, 0xf1, 0xc8, 0xf3, 0x9d,
    0xaa, 0xb8, 0x7b, 0xb4, 0x7c, 0xee, 0x23, 0xe8, 0xf8, 0x9d, 0xde, 0xf9,
    0x2d, 0x48, 0x25, 0x84, 0x54, 0x08, 0x15, 0xa4, 0xb0, 0x90, 0x32, 0xa8,
    0xb4, 0xb1, 0x8a, 0x14, 0x6c, 0x02, 0xa7, 0x76, 0x79, 0x1b, 0xbb, 0x5b,
    0x2f, 0x51, 0x8e, 0x6b, 0x85, 0x32, 0x88, 0x9c, 0xba, 0xf6, 0x20, 0x85,
    0x08, 0xbf, 0x1b, 0x27, 0x65, 0x55, 0x68, 0xb0, 0x8e, 0xa2, 0xd0, 0x6c,
    0x3d, 0x76, 0xb1, 0x08, 0x49, 0x66, 0x1c, 0xa6, 0xd7, 0x2b, 0x2e, 0x1e,
    0x39, 0x74, 0xd8, 0xf4, 0x57, 0x7f, 0xb3, 0xff, 0xc8, 0xff, 0xf8, 0xad,
    0xcd, 0xef, 0xfe, 0x9a, 0x00, 0x00, 0x60, 0xce, 0x7c, 0xf3, 0xb4, 0x39,
    0xf3, 0xcd, 0xf7, 0xa1, 0xe2, 0x54, 0xdd, 0xfa, 0x77, 0xce, 0x0a, 0x21,
    0x67, 0x10, 0x41, 0x99, 0x09, 0xad, 0x03, 0x10, 0x2a, 0x88, 0xa0, 0x70,
    0x0f, 0x72, 0x95, 0x31, 0x28, 0x52, 0x06, 0x8b, 0x91, 0x02, 0x21, 0x42,
    0x86, 0x49, 0x0a, 0x81, 0x12, 0xa1, 0xa5, 0x76, 0x5c, 0x34, 0x1d, 0x2f,
    0x5c, 0xd5, 0x97, 0x1c, 0x2f, 0x5e, 0x6b, 0x74, 0x24, 0x89, 0x54, 0x38,
    0x0e, 0x0e, 0xb0, 0x3e, 0x04, 0x71, 0xf3, 0x37, 0xcc, 0x7f, 0xe4, 0xe8,
    0xc7, 0x7e, 0xed, 0xa3, 0x57, 0x7b, 0xef, 0x57, 0xd4, 0x21, 0xf2, 0xaa,
    0x86, 0x2d, 0x4b, 0x5f, 0xe5, 0x07, 0xc3, 0xd9, 0x0e, 0x84, 0x15, 0x9a,
    0x9f, 0x42, 0x6f, 0x4f, 0x48, 0x9f, 0x8f, 0x2f, 0xb9, 0xe9, 0x2e, 0x37,
    0x76, 0x5b, 0xc8, 0xd0, 0x17, 0x14, 0xac, 0x45, 0xd6, 0x8d, 0x51, 0xf5,
    0x82, 0xb5, 0x42, 0xeb, 0x7a, 0xc1, 0x5a, 0x13, 0x69, 0x45, 0x1c, 0x45,
    0xc4, 0xb1, 0x22, 0xd6, 0xaa, 0x6e, 0xb7, 0x0f, 0xcf, 0xf4, 0x02, 0x8c,
    0x83, 0x0b, 0xdf, 0xf8, 0xf2, 0x53, 0x7c, 0x8f, 0xcd, 0x7e, 0xed, 0x01,
    0x00, 0xe9, 0x2f, 0x3d, 0xf9, 0x4b, 0x36, 0xef, 0xbf, 0x68, 0x2b, 0x87,
    0x35, 0x60, 0x7d, 0xcd, 0x61, 0x21, 0xa8, 0x08, 0x56, 0x30, 0x5e, 0xb0,
    0xae, 0x77, 0xff, 0x0a, 0xb5, 0x85, 0xa3, 0x42, 0xbd, 0xbb, 0xba, 0xde,
    0x79, 0xa9, 0x50, 0x4a, 0x13, 0x4b, 0x85, 0xae, 0x81, 0xd4, 0x5a, 0x13,
    0x45, 0x11, 0x51, 0x24, 0x51, 0x4a, 0x86, 0x3c, 0xa3, 0x10, 0x38, 0x04,
    0xc6, 0x7b, 0x46, 0x06, 0x4e, 0x3e, 0xfc, 0xa7, 0xbf, 0xff, 0xc2, 0x1f,
    0xfe, 0xfa, 0x61, 0x10, 0x57, 0x05, 0xe0, 0x7a, 0xfc, 0xbf, 0x80, 0xa2,
    0x58, 0xb3, 0x7e, 0xed, 0xf8, 0xc3, 0x64, 0xb3, 0xb3, 0x22, 0x9d, 0xdc,
    0x2d, 0x54, 0xac, 0xa4, 0xd2, 0x08, 0xad, 0x43, 0x8e, 0x3f, 0x0a, 0x7d,
    0x40, 0x52, 0xeb, 0xda, 0x77, 0x2b, 0x90, 0x81, 0xbd, 0x55, 0xdd, 0x06,
    0xa7, 0x54, 0xbd, 0xe3, 0x72, 0xfc, 0x59, 0x5d, 0xf9, 0x5c, 0xff, 0x5d,
    0x60, 0xfc, 0x2b, 0xc9, 0x1a, 0x08, 0xa6, 0x9f, 0x3b, 0xb8, 0x78, 0xee,
    0xdc, 0xe5, 0x6f, 0xfc, 0xce, 0x7f, 0xfa, 0xd4, 0x37, 0x3f, 0xf1, 0xaf,
    0xff, 0x10, 0xef, 0x3b, 0x78, 0xdf, 0x25, 0x88, 0xbb, 0xeb, 0x0e, 0x80,
    0x04, 0x91, 0xe0, 0x4a, 0xe5, 0x2e, 0x3d, 0x7b, 0xa8, 0xba, 0x70, 0xe4,
    0x2f, 0x9c, 0x4c, 0xac, 0x43, 0x36, 0x45, 0xdc, 0x6c, 0x23, 0xb4, 0x08,
    0x11, 0x4f, 0x20, 0x29, 0x5f, 0x93, 0x15, 0x75, 0x9d, 0x71, 0x23, 0xd4,
    0x16, 0xb2, 0x16, 0x3e, 0x81, 0x28, 0x85, 0x08, 0x35, 0x82, 0xe0, 0x1b,
    0xe5, 0x46, 0x81, 0xc4, 0x51, 0x47, 0x7d, 0x5e, 0xd0, 0x5d, 0xef, 0xe4,
    0xa7, 0x9f, 0xfe, 0xf6, 0xf1, 0x83, 0x9f, 0xfe, 0x2f, 0x5f, 0x78, 0xf0,
    0x57, 0xff, 0xd9, 0x67, 0x2f, 0x1c, 0x3a, 0xf8, 0x2c, 0xde, 0xad, 0xe0,
    0xdd, 0x25, 0xbc, 0xeb, 0x13, 0x44, 0xdd, 0x4b, 0xc6, 0xf5, 0xf8, 0x9f,
    0x21, 0x09, 0x22, 0x45, 0xca, 0x39, 0x21, 0xe4, 0x02, 0x52, 0xce, 0x22,
    0xe4, 0x04, 0x88, 0x96, 0x6a, 0xcf, 0xdf, 0x90, 0xec, 0x38, 0xb0, 0x2f,
    0x5d, 0xba, 0xe9, 0xc6, 0x64, 0x7a, 0x6e, 0x6b, 0x3a, 0xbf, 0xb4, 0x25,
    0x9d, 0x99, 0x6b, 0x24, 0x59, 0x2a, 0xa2, 0x24, 0x0e, 0x39, 0x3d, 0x15,
    0xa1, 0x23, 0xb5, 0xc1, 0x17, 0x5a, 0xe9, 0x4d, 0x0a, 0x2f, 0x30, 0xbe,
    0x94, 0x0a, 0x5b, 0x95, 0x76, 0xb4, 0x72, 0xbe, 0x3b, 0x5a, 0x39, 0xd7,
    0x59, 0x3f, 0x7b, 0xe2, 0xd2, 0x85, 0x27, 0x0f, 0x9e, 0xbd, 0xf0, 0xc4,
    0xd7, 0x4e, 0x9a, 0x7c, 0xb4, 0x0e, 0xbe, 0xe7, 0x9d, 0xbb, 0x8c, 0xb3,
    0xe7, 0xbd, 0xb3, 0xa7, 0x70, 0xf6, 0x3c, 0xf8, 0x01, 0x63, 0x9f, 0x7b,
    0x9d, 0x01, 0x80, 0x10, 0xa3, 0x65, 0x48, 0x39, 0x2d, 0x84, 0x9c, 0x45,
    0xc8, 0x39, 0xa4, 0x98, 0x02, 0xd9, 0x16, 0x42, 0x64, 0x08, 0xd1, 0x00,
    0x91, 0x20, 0x65, 0xa2, 0x1a, 0x13, 0x13, 0xd1, 0xe4, 0xfc, 0xb4, 0x6e,
    0x4d, 0x37, 0xa3, 0xc9, 0xd9, 0x46, 0xdc, 0x9e, 0xca, 0x74, 0xd6, 0x8c,
    0x54, 0x94, 0x28, 0xa9, 0x54, 0x50, 0x44, 0xa6, 0x74, 0x66, 0xd4, 0xaf,
    0xaa, 0xc1, 0x7a, 0x69, 0xba, 0xab, 0x79, 0xde, 0x59, 0x1e, 0x16, 0xab,
    0x17, 0xfa, 0x26, 0x1f, 0x16, 0x78, 0x5f, 0x81, 0x2f, 0xf1, 0x8c, 0xf0,
    0x6e, 0x80, 0xf7, 0xeb, 0xde, 0xdb, 0x15, 0x9c, 0x3b, 0xef, 0x9d, 0x3b,
    0x87, 0xb3, 0x2b, 0xe0, 0x87, 0x5c, 0x65, 0xf7, 0xaf, 0x27, 0x00, 0x10,
    0x08, 0x36, 0x46, 0xc8, 0x26, 0x42, 0x4e, 0x0a, 0x21, 0x66, 0x10, 0x72,
    0x0a, 0x21, 0x26, 0x10, 0xb2, 0x25, 0x04, 0x19, 0x42, 0xa4, 0x20, 0x12,
    0x10, 0x11, 0x82, 0x28, 0x64, 0x03, 0x50, 0x80, 0x44, 0x08, 0xc5, 0x58,
    0x24, 0x6c, 0x94, 0x4d, 0xea, 0x3a, 0xb4, 0xc7, 0x02, 0x06, 0x7c, 0x85,
    0xf7, 0x05, 0xde, 0x0f, 0xf1, 0xbe, 0xeb, 0xbd, 0x5b, 0xc3, 0xbb, 0x15,
    0xef, 0xdc, 0x32, 0xde, 0xad, 0xd6, 0x66, 0x5f, 0x72, 0x95, 0x9d, 0xff,
    0xcb, 0x00, 0x60, 0x3c, 0xbf, 0x0c, 0x0b, 0x14, 0x69, 0xbd, 0xf3, 0x2d,
    0x21, 0x44, 0x8b, 0x70, 0x35, 0x40, 0x64, 0x08, 0x91, 0x0a, 0x44, 0x12,
    0x22, 0x4d, 0xa1, 0x6b, 0x10, 0xd4, 0x86, 0x63, 0xf0, 0x1b, 0x71, 0x48,
    0x58, 0xb8, 0xf7, 0xa5, 0xc7, 0xe7, 0x78, 0x3f, 0x02, 0x3f, 0xc0, 0xbb,
    0xae, 0xf7, 0xf4, 0xf0, 0xae, 0x87, 0xf7, 0x7d, 0xbc, 0x1b, 0x31, 0x8e,
    0x66, 0x5f, 0xc1, 0x0b, 0xfe, 0x65, 0x8d, 0x40, 0xd3, 0x08, 0x5d, 0xef,
    0x76, 0x5c, 0xdf, 0x13, 0x10, 0x89, 0x10, 0x22, 0x86, 0x71, 0xc8, 0x2d,
    0x54, 0xfd, 0xf7, 0xe3, 0xf7, 0x73, 0x61, 0xd7, 0xbd, 0x01, 0x8c, 0xf7,
    0xbe, 0x04, 0x5f, 0x80, 0x2f, 0xf0, 0x14, 0xe1, 0x08, 0xf8, 0x8a, 0x71,
    0xe4, 0x7a, 0x95, 0xa0, 0xed, 0x7b, 0x8d, 0xbf, 0x4c, 0x00, 0xbe, 0xf3,
    0xb9, 0x9b, 0x2f, 0x59, 0xeb, 0x62, 0xb9, 0xa1, 0x85, 0x37, 0xfe, 0x4e,
    0x8c, 0x55, 0x44, 0x48, 0x0c, 0xd6, 0x89, 0x6f, 0x18, 0xff, 0xcc, 0x95,
    0x80, 0xe2, 0x1a, 0x5f, 0xe4, 0xff, 0xc7, 0xf1, 0x9d, 0xef, 0xf5, 0x8a,
    0x77, 0xf4, 0xd5, 0x8e, 0xff, 0x07, 0x1f, 0x6f, 0xda, 0x27, 0xab, 0x48,
    0xdd, 0x83, 0x00, 0x00, 0x00, 0x00, 0x49, 0x45, 0x4e, 0x44, 0xae, 0x42,
    0x60, 0x82
};



msnShadowItemMsg::msnShadowItemMsg(QListView *parent, QString _ip1, QString _ip2, QString _nick1, QString _nick2, QString _msg, QListViewItem *last, msnShadowItemChat *_chat, QString _packetTime) : QListViewItem(parent, last) {

ip1 = _ip1;
ip2 = _ip2;
nick1 = _nick1.mid(0, _nick1.find("@"));
nick2 = _nick2.mid(0, _nick2.find("@"));
msg = _msg;
chat = _chat;
packetTime = _packetTime;


}


void msnShadowItemMsg::paintCell(QPainter *p, const QColorGroup &cg, int ,int width, int) {
QPixmap pix(width, height());
pix.fill(Qt::black);
QImage img;
img.loadFromData(image1_data,sizeof( image1_data ), "PNG" );
QPixmap pixao(img);

QPainter *p2 = new QPainter(&pix);
QFont fontz;
fontz.setBold(true);
fontz.setPointSize(15);
p2->setFont(fontz);
p2->setPen(Qt::gray);
p2->drawText(100,10,600,100,0,QString("%1%2 says to %3 :").arg(packetTime).arg(nick1).arg(nick2));
fontz.setPointSize(15);
p2->setFont(fontz);


int lenStr = msg.length();
int nStr = 0;
if(lenStr == 46)
nStr = 1;
else
nStr = (lenStr / 46) + 1;
int offset = 0;
int h = 60;
for(int i = 0; i < nStr; i++) {
p2->drawText(100,h,width,100,0,msg.mid(offset,46));
offset += 46;
h += 20;

}
setHeight(100+((nStr-1)*20));
p2->drawPixmap(0,0,pixao);

delete p2;
p->drawPixmap(0,0,pix);


}

void msnShadowItemMsg::setup() {
setHeight(100);
}

